@@ -1,5 +1,4 @@
-/* $Id: adaproject_part.cpp,v 1.17 2004/04/19 21:30:36 dagerbo Exp $
- * Copyright (C) 2003 Oliver Kellogg
+/* Copyright (C) 2003 Oliver Kellogg
  * okellogg@users.sourceforge.net
  *
  * This program is free software; you can redistribute it and/or modify
@@ -35,6 +34,7 @@
 #include "kdevlanguagesupport.h"
 #include "kdevcompileroptions.h"
 #include "kdevgenericfactory.h"
+#include <kdevplugininfo.h>
 
 #include "adaproject_widget.h"
 #include "adaproject_part.h"
@@ -42,11 +42,11 @@
 #include "adaglobaloptionsdlg.h"
 
 typedef KDevGenericFactory<AdaProjectPart> AdaProjectFactory;
-static const KAboutData data("kdevadaproject", I18N_NOOP("Build Tool"), "1.0");
-K_EXPORT_COMPONENT_FACTORY( libkdevadaproject, AdaProjectFactory( &data ) )
+static const KDevPluginInfo data("kdevadaproject");
+K_EXPORT_COMPONENT_FACTORY( libkdevadaproject, AdaProjectFactory( data ) )
 
 AdaProjectPart::AdaProjectPart(QObject *parent, const char *name, const QStringList& )
-    :KDevProject("AdaProject", "adaproject", parent, name ? name : "AdaProjectPart" )
+    :KDevBuildTool(&data, parent, name ? name : "AdaProjectPart" )
 {
     setInstance(AdaProjectFactory::instance());
     setXMLFile("kdevadaproject.rc");
@@ -340,7 +340,8 @@ void AdaProjectPart::removeFiles(const QStringList& /*fileList*/)
 
 void AdaProjectPart::slotBuild()
 {
-    partController()->saveAllFiles();
+    if (partController()->saveAllFiles()==false)
+       return; //user cancelled
 
     QString cmdline = m_compilerExec + " " + m_compilerOpts + " ";
 
