@@ -51,17 +51,18 @@
 #include <envvartools.h>
 
 #include <configwidgetproxy.h>
+#include <kdevplugininfo.h>
 
 #define CONFIGURE_OPTIONS 1
 #define RUN_OPTIONS 2
 #define MAKE_OPTIONS 3
 
-static const KAboutData data("kdevautoproject", I18N_NOOP("Automake Manager"), "1.0");
+static const KDevPluginInfo data("kdevautoproject");
 
-K_EXPORT_COMPONENT_FACTORY( libkdevautoproject, AutoProjectFactory( &data ) )
+K_EXPORT_COMPONENT_FACTORY( libkdevautoproject, AutoProjectFactory( data ) )
 
 AutoProjectPart::AutoProjectPart(QObject *parent, const char *name, const QStringList &args)
-    : KDevProject("AutoProject", "make", parent, name ? name : "AutoProjectPart")
+    : KDevBuildTool(&data, parent, name ? name : "AutoProjectPart")
     , m_lastCompilationFailed(false)
 {
     setInstance(AutoProjectFactory::instance());
@@ -73,7 +74,7 @@ AutoProjectPart::AutoProjectPart(QObject *parent, const char *name, const QStrin
     m_needMakefileCvs = false;
 
     m_widget = new AutoProjectWidget(this, m_isKDE);
-	m_widget->setIcon(SmallIcon( icon() ));
+    m_widget->setIcon(SmallIcon( info()->icon() ));
     m_widget->setCaption(i18n("Automake Manager"));
     QWhatsThis::add(m_widget, i18n("<b>Automake manager</b><p>"
                                    "The project tree consists of two parts. The 'overview' "
@@ -221,11 +222,11 @@ AutoProjectPart::AutoProjectPart(QObject *parent, const char *name, const QStrin
 
 //    connect( core(), SIGNAL(projectConfigWidget(KDialogBase*)), this, SLOT(projectConfigWidget(KDialogBase*)) );
 
-	_configProxy = new ConfigWidgetProxy( core() );
-	_configProxy->createProjectConfigPage( i18n("Configure Options"), CONFIGURE_OPTIONS, icon() );
-	_configProxy->createProjectConfigPage( i18n("Run Options"), RUN_OPTIONS, icon() );
-	_configProxy->createProjectConfigPage( i18n("Make Options"), MAKE_OPTIONS, icon() );
-	connect( _configProxy, SIGNAL(insertConfigWidget(const KDialogBase*, QWidget*, unsigned int )), this, SLOT(insertConfigWidget(const KDialogBase*, QWidget*, unsigned int )) );
+    _configProxy = new ConfigWidgetProxy( core() );
+    _configProxy->createProjectConfigPage( i18n("Configure Options"), CONFIGURE_OPTIONS, info()->icon() );
+    _configProxy->createProjectConfigPage( i18n("Run Options"), RUN_OPTIONS, info()->icon() );
+    _configProxy->createProjectConfigPage( i18n("Make Options"), MAKE_OPTIONS, info()->icon() );
+    connect( _configProxy, SIGNAL(insertConfigWidget(const KDialogBase*, QWidget*, unsigned int )), this, SLOT(insertConfigWidget(const KDialogBase*, QWidget*, unsigned int )) );
 
 
     connect( makeFrontend(), SIGNAL(commandFinished(const QString&)),
@@ -311,7 +312,7 @@ void AutoProjectPart::openProject(const QString &dirName, const QString &project
 
     QDomDocument &dom = *projectDom();
     QString activeTarget = DomUtil::readEntry(dom, "/kdevautoproject/general/activetarget");
-    kdDebug(9020) << "activeTarget " << activeTarget << endl;
+    kdDebug(9020) << k_funcinfo << "activeTarget " << activeTarget << endl;
     if (!activeTarget.isEmpty())
         m_widget->setActiveTarget(activeTarget);
 
@@ -410,12 +411,12 @@ QString AutoProjectPart::mainProgram(bool relative) const
         TargetItem* titem = m_widget->activeTarget();
 
         if ( !titem ) {
-            kdDebug ( 9000 ) << "Error! : No Main Program was specified and there's no active target! -> Unable to determine the main program in AutoProjectPart::mainProgram()" << endl;
+            kdDebug ( 9020 ) << k_funcinfo << "Error! : No Main Program was specified and there's no active target! -> Unable to determine the main program in AutoProjectPart::mainProgram()" << endl;
             return QString::null;
         }
 
         if ( titem->primary != "PROGRAMS" ) {
-            kdDebug ( 9000 ) << "Error! : No Main Program was specified and active target isn't binary (" << titem->primary << ") ! -> Unable to determine the main program in AutoProjectPart::mainProgram()" << endl;
+            kdDebug ( 9020 ) << k_funcinfo << "Error! : No Main Program was specified and active target isn't binary (" << titem->primary << ") ! -> Unable to determine the main program in AutoProjectPart::mainProgram()" << endl;
             return QString::null;
         }
 
@@ -553,9 +554,9 @@ void AutoProjectPart::addFiles ( const QStringList& fileList )
 			if ( !messageBoxShown )
 			{
 				KMessageBox::information(m_widget, i18n("The directory you selected is not the active directory.\n"
-														"You should 'activate' the target you're currently working on in Automake Manager.\n"
-														"Just right-click a target and choose 'Make Target Active'."),
-														i18n ( "No Active Target Found" ), "No automake manager active target warning" );
+									"You should 'activate' the target you're currently working on in Automake Manager.\n"
+									"Just right-click a target and choose 'Make Target Active'."),
+									i18n ( "No Active Target Found" ), "No automake manager active target warning" );
 				messageBoxShown = true;
 			}
 		}
@@ -591,7 +592,7 @@ QStringList AutoProjectPart::allBuildConfigs() const
     QDomElement childEl = node.firstChild().toElement();
     while (!childEl.isNull()) {
         QString config = childEl.tagName();
-        kdDebug(9020) << "Found config " << config << endl;
+        kdDebug(9020) << k_funcinfo << "Found config " << config << endl;
         if (config != "default")
             allConfigs.append(config);
         childEl = childEl.nextSibling().toElement();
@@ -651,16 +652,16 @@ QString AutoProjectPart::constructMakeCommandLine(const QString &dir, const QStr
                                                               "and no configure script for this project.\n"
                                                               "Run automake & friends and configure first?"));
             if (r == KMessageBox::No)
-                return 0;
+              return QString::null;
             preCommand = makefileCvsCommand();
             if (preCommand.isNull())
-                return 0;
+              return QString::null;
             preCommand += " && ";
             preCommand += configureCommand() + " && ";
         } else {
             int r = KMessageBox::questionYesNo(m_widget, i18n("There is no Makefile in this directory. Run 'configure' first?"));
             if (r == KMessageBox::No)
-                return 0;
+              return QString::null;
             preCommand = configureCommand() + " && ";
         }
     }
@@ -669,7 +670,7 @@ QString AutoProjectPart::constructMakeCommandLine(const QString &dir, const QStr
     QString cmdline = DomUtil::readEntry(dom, "/kdevautoproject/make/makebin");
     int prio = DomUtil::readIntEntry(dom, "/kdevautoproject/make/prio");
     QString nice;
-    kdDebug(9020) << "constructMakeCommandLine() nice = " << prio<< endl;
+    kdDebug(9020) << k_funcinfo << "nice = " << prio<< endl;
     if (prio != 0) {
         nice = QString("nice -n%1 ").arg(prio);
     }
@@ -701,7 +702,8 @@ QString AutoProjectPart::constructMakeCommandLine(const QString &dir, const QStr
 
 void AutoProjectPart::startMakeCommand(const QString &dir, const QString &target, bool withKdesu)
 {
-    partController()->saveAllFiles();
+    if (partController()->saveAllFiles()==false)
+       return; //user cancelled
 
     m_buildCommand = constructMakeCommandLine(dir, target);
 
@@ -727,16 +729,9 @@ void AutoProjectPart::queueInternalLibDependenciesBuild(TargetItem* titem)
   for (l2it = l2.begin(); l2it != l2.end(); ++l2it) {
     QString dependency = *l2it;
     if (dependency.startsWith("$(top_builddir)/")) {
-        // These are the internal libraries
-#if KDE_VERSION > 305
-        dependency.remove("$(top_builddir)/");
-#else
-        QString topBuildDirStr("$(top_builddir)/");
-        int i = dependency.find(topBuildDirStr);
-        if (i != -1) {
-        dependency.remove(i, i + topBuildDirStr.length() - 1);
-    }
-#endif
+       // These are the internal libraries
+      dependency.remove("$(top_builddir)/");
+
       tdir = buildDirectory();
       if (!tdir.endsWith("/") && !tdir.isEmpty())
         tdir += "/";
@@ -753,7 +748,7 @@ void AutoProjectPart::queueInternalLibDependenciesBuild(TargetItem* titem)
       SubprojectItem *spi = m_widget->subprojectItemForPath( dependency.left(pos) );
       if (spi) {
         QPtrList< TargetItem > tl = spi->targets;
-        // Cycle throught the list of targets to find the one we're looking for
+        // Cycle through the list of targets to find the one we're looking for
         TargetItem *ti = tl.first();
         do {
           if (ti->name == tname) {
@@ -1089,7 +1084,7 @@ void AutoProjectPart::executeTarget(const QDir& dir, const TargetItem* titem)
 	bool inTerminal = DomUtil::readBoolEntry(*projectDom(), "/kdevautoproject/run/terminal");
 	
 	QString program = environString();
-	if(titem->name.startsWith("/"))
+	if(!titem->name.startsWith("/"))
 	  program += "./";
 	program += titem->name;	
 	
@@ -1205,15 +1200,15 @@ void AutoProjectPart::savePartialProjectSession ( QDomElement* el )
 
     KMessageBox::information ( 0, "Hallo, Welt!" );
 
-    kdDebug ( 9000 ) << "*********************************************** 1) AutoProjectPart::savePartialProjectSession()" << endl;
+    kdDebug ( 9020 ) << k_funcinfo << "1" << endl;
 
     if ( domDoc.isNull() )
     {
-        kdDebug ( 9000 ) << "*********************************************** 2) AutoProjectPart::savePartialProjectSession()" << endl;
+        kdDebug ( 9020 ) << k_funcinfo << "2" << endl;
         return;
     }
 
-    kdDebug ( 9000 ) << "*********************************************** 3) AutoProjectPart::savePartialProjectSession()" << endl;
+    kdDebug ( 9020 ) << k_funcinfo << "3" << endl;
 
     m_widget->saveSession ( el );
 }
@@ -1327,7 +1322,7 @@ QStringList AutoProjectPart::distFiles() const
 	QString projectDir = projectDirectory();
 	QDir dir(projectDir);
 	QDir admin(projectDir +"/admin");
-	QStringList files = dir.entryList( "Makefile.cvs Makefile.am configure* INSTALL README NEWS TODO ChangeLog COPYING AUTHORS stamp-h.in");
+	QStringList files = dir.entryList( "Makefile.cvs Makefile.am configure* INSTALL README NEWS TODO ChangeLog COPYING AUTHORS stamp-h.in acinclude.m4 config.h.in Makefile.in");
 	QStringList adminFiles = admin.entryList(QDir::Files);
 	QStringList::Iterator idx = adminFiles.begin();
 	for( ; idx != adminFiles.end(); ++idx)
@@ -1342,7 +1337,30 @@ QStringList AutoProjectPart::distFiles() const
 	}
 	return sourceList + files;
 }
+
+void AutoProjectPart::startSimpleMakeCommand( const QString & dir, const QString & command, bool withKdesu )
+{
+	if (partController()->saveAllFiles()==false)
+		return; //user cancelled
+	
+//	m_buildCommand = constructMakeCommandLine(dir, target);
+	
+	QString cmdline = command;
+	cmdline.prepend(makeEnvironment());
+	
+	QString dircmd = "cd ";
+	dircmd += KProcess::quote(dir);
+	dircmd += " && ";
+	
+	m_buildCommand = dircmd + cmdline;
+	
+	if (withKdesu)
+		m_buildCommand = "kdesu -t -c '" + m_buildCommand + "'";
+	
+	if (!m_buildCommand.isNull())
+		makeFrontend()->queueCommand(dir, m_buildCommand);
+}
+
 #include "autoprojectpart.moc"
 
-
-
+// kate: space-indent off; indent-width 8; tab-width 8; show-tabs on;
