@@ -50,13 +50,14 @@
 #include "envvartools.h"
 #include "urlutil.h"
 
+#include <kdevplugininfo.h>
 
 typedef KDevGenericFactory<CustomProjectPart> CustomProjectFactory;
-static const KAboutData data("kdevcustomproject", I18N_NOOP("Build Tool"), "1.0");
-K_EXPORT_COMPONENT_FACTORY( libkdevcustomproject, CustomProjectFactory( &data ) )
+static const KDevPluginInfo data("kdevcustomproject");
+K_EXPORT_COMPONENT_FACTORY( libkdevcustomproject, CustomProjectFactory( data ) )
 
 CustomProjectPart::CustomProjectPart(QObject *parent, const char *name, const QStringList &)
-    : KDevProject("CustomProject", "customproject", parent, name ? name : "CustomProjectPart")
+    : KDevBuildTool(&data, parent, name ? name : "CustomProjectPart")
 	, m_lastCompilationFailed(false)
 {
     setInstance(CustomProjectFactory::instance());
@@ -105,6 +106,9 @@ CustomProjectPart::CustomProjectPart(QObject *parent, const char *name, const QS
                             "Environment variables and make arguments can be specified "
                             "in the project settings dialog, <b>Build Options</b> tab."));
 
+    m_targetObjectFilesMenu = new QPopupMenu();
+    m_targetOtherFilesMenu = new QPopupMenu();
+
     m_makeEnvironmentsSelector = new KSelectAction( i18n("Make &Environment"),0,
                             actionCollection(), "build_make_environment" );
     m_makeEnvironmentsSelector->setToolTip(i18n("Make environment"));
@@ -116,6 +120,10 @@ CustomProjectPart::CustomProjectPart(QObject *parent, const char *name, const QS
              this, SLOT(updateTargetMenu()) );
     connect( m_targetMenu, SIGNAL(activated(int)),
              this, SLOT(targetMenuActivated(int)) );
+    connect( m_targetObjectFilesMenu, SIGNAL(activated(int)),
+             this, SLOT(targetObjectFilesMenuActivated(int)) );
+    connect( m_targetOtherFilesMenu, SIGNAL(activated(int)),
+             this, SLOT(targetOtherFilesMenuActivated(int)) );
     connect( m_makeEnvironmentsSelector->popupMenu(), SIGNAL(aboutToShow()),
              this, SLOT(updateMakeEnvironmentsMenu()) );
     connect( m_makeEnvironmentsSelector->popupMenu(), SIGNAL(activated(int)),
@@ -139,10 +147,10 @@ CustomProjectPart::~CustomProjectPart()
 void CustomProjectPart::projectConfigWidget(KDialogBase *dlg)
 {
     QVBox *vbox;
-    vbox = dlg->addVBoxPage(i18n("Run Options"));
+    vbox = dlg->addVBoxPage(i18n("Run Options"), i18n("Run Options"), BarIcon( "make", KIcon::SizeMedium ));
     RunOptionsWidget *w1 = new RunOptionsWidget(*projectDom(), "/kdevcustomproject", buildDirectory(), vbox);
     connect( dlg, SIGNAL(okClicked()), w1, SLOT(accept()) );
-    vbox = dlg->addVBoxPage(i18n("Build Options"));
+    vbox = dlg->addVBoxPage(i18n("Build Options"), i18n("Build Options"), BarIcon( "make", KIcon::SizeMedium ));
     QTabWidget *buildtab = new QTabWidget(vbox);
 
     CustomBuildOptionsWidget *w2 = new CustomBuildOptionsWidget(*projectDom(), buildtab);
@@ -162,9 +170,10 @@ void CustomProjectPart::contextMenu(QPopupMenu *popup, const Context *context)
         return;
 
     const FileContext *fcontext = static_cast<const FileContext*>(context);
-    if (fcontext->isDirectory()) {
+    KURL url = fcontext->urls().first();
+    if (URLUtil::isDirectory(url)) {
         // remember the name of the directory
-        m_contextDirName = fcontext->fileName();
+        m_contextDirName = url.fileName();
         m_contextDirName = m_contextDirName.mid ( project()->projectDirectory().length() + 1 );
         popup->insertSeparator();
         int id = popup->insertItem( i18n("Make Active Directory"),
@@ -179,7 +188,7 @@ void CustomProjectPart::contextMenu(QPopupMenu *popup, const Context *context)
 
     if( fcontext->urls().size() == 1 )
     {
-        QString contextFileName = URLUtil::canonicalPath(fcontext->fileName());
+        QString contextFileName = URLUtil::canonicalPath(fcontext->urls().first().fileName());
         bool inProject = project()->isProjectFile(contextFileName);
         QString popupstr = QFileInfo(contextFileName).fileName();
         if (contextFileName.startsWith(projectDirectory()+ "/"))
@@ -274,11 +283,11 @@ void CustomProjectPart::openProject(const QString &dirName, const QString &proje
      in order to support completely-out-of-source builds, where nothing, not
      even the kdevelop project files are created in the source directory, Alex <neundorf@kde.org>
      */
-    QString filelistDir=DomUtil::readEntry(dom, "/kdevcustomproject/filelistdirectory");
-    if (filelistDir.isEmpty())
-       filelistDir=dirName;
+    m_filelistDir=DomUtil::readEntry(dom, "/kdevcustomproject/filelistdirectory");
+    if (m_filelistDir.isEmpty())
+       m_filelistDir=dirName;
 
-    QFile f(filelistDir + "/" + projectName + ".filelist");
+    QFile f(m_filelistDir + "/" + projectName + ".filelist");
     if (f.open(IO_ReadOnly)) {
         QTextStream stream(&f);
         while (!stream.atEnd()) {
@@ -327,17 +336,33 @@ void CustomProjectPart::populateProject()
             QPtrListIterator<QFileInfo> it(*dirEntries);
             for (; it.current(); ++it) {
                 QString fileName = it.current()->fileName();
-                if (fileName == "." || fileName == "..")
-                    continue;
                 QString path = it.current()->absFilePath();
+                if (fileName == "." || fileName == ".."){
+                    continue;
+                }
                 if (it.current()->isDir()) {
-                    kdDebug(9025) << "Pushing: " << path << endl;
-                    s.push(path);
+                      kdDebug(9025) << "Pushing: " << path << endl;
+                      s.push(path);
+                      continue;
                 }
-                else {
-                        kdDebug(9025) << "Adding: " << path << endl;
+                if ((!fileName.endsWith("~"))
+                    && ((fileName.endsWith(".java"))
+                        || (fileName.endsWith(".h"))
+                        || (fileName.endsWith(".H"))
+                        || (fileName.endsWith(".hh"))
+                        || (fileName.endsWith(".hxx"))
+                        || (fileName.endsWith(".hpp"))
+                        || (fileName.endsWith(".c"))
+                        || (fileName.endsWith(".C"))
+                        || (fileName.endsWith(".cc"))
+                        || (fileName.endsWith(".cpp"))
+                        || (fileName.endsWith(".c++"))
+                        || (fileName.endsWith(".cxx"))
+                        || (fileName.startsWith("Makefile"))))  //Makefile, Makefile.am, Makefile.in
+                {
+                    kdDebug(9025) << "Adding: " << path << endl;
                     m_sourceFiles.append(path.mid(prefixlen));
-                }
+                 }
             }
         }
     } while (!s.isEmpty());
@@ -353,7 +378,7 @@ void CustomProjectPart::closeProject()
 
 void CustomProjectPart::saveProject()
 {
-    QFile f(m_projectDirectory + "/" + m_projectName + ".filelist");
+    QFile f(m_filelistDir + "/" + m_projectName + ".filelist");
     if (!f.open(IO_WriteOnly))
         return;
 
@@ -559,7 +584,8 @@ QString CustomProjectPart::makeEnvironment() const
 
 void CustomProjectPart::startMakeCommand(const QString &dir, const QString &target)
 {
-    partController()->saveAllFiles();
+    if (partController()->saveAllFiles()==false)
+       return; //user cancelled
 
     QDomDocument &dom = *projectDom();
     bool ant = DomUtil::readEntry(dom, "/kdevcustomproject/build/buildtool") == "ant";
@@ -584,7 +610,8 @@ void CustomProjectPart::startMakeCommand(const QString &dir, const QString &targ
     }
 
     cmdline += " ";
-    cmdline += target;
+    if (!target.isEmpty())
+       cmdline += KProcess::quote(target);
 
     QString dircmd = "cd ";
     dircmd += KProcess::quote(dir);
@@ -606,7 +633,7 @@ void CustomProjectPart::startMakeCommand(const QString &dir, const QString &targ
 void CustomProjectPart::slotBuild()
 {
     m_lastCompilationFailed = false;
-    startMakeCommand(buildDirectory(), QString::fromLatin1(""));
+    startMakeCommand(buildDirectory(), DomUtil::readEntry(*projectDom(), "/kdevcustomproject/make/defaulttarget"));
 }
 
 
@@ -686,11 +713,14 @@ void CustomProjectPart::slotExecute()
     appFrontend()->startAppCommand(runDirectory(), program, inTerminal);
 }
 
-
 void CustomProjectPart::updateTargetMenu()
 {
     m_targets.clear();
+    m_targetsObjectFiles.clear();
+    m_targetsOtherFiles.clear();
     m_targetMenu->clear();
+    m_targetObjectFilesMenu->clear();
+    m_targetOtherFilesMenu->clear();
 
     QDomDocument &dom = *projectDom();
     bool ant = DomUtil::readEntry(dom, "/kdevcustomproject/build/buildtool") == "ant";
@@ -716,45 +746,96 @@ void CustomProjectPart::updateTargetMenu()
             node = node.nextSibling();
         }
     } else {
-    	kdDebug(9025) << "Trying to load a makefile... " << endl;
-        QFile f(buildDirectory() + "/Makefile");
-	if (!f.exists())
-	    f.setName( buildDirectory() + "/makefile" );
-        if (!f.open(IO_ReadOnly)) {
-            kdDebug(9025) << "No Makefile" << endl;
-            return;
-        }
-        QTextStream stream(&f);
-        //QRegExp re(".PHONY\\s*:(.*)");
-	QRegExp re("^([^($%.#][^)\\s]+):.*$");
-	re.setMinimal(true);
-	QString str = "";
-        while (!stream.atEnd()) {
-            QString str = stream.readLine();
-            // Read all continuation lines
-	    // kdDebug(9025) << "Trying: " << str.simplifyWhiteSpace() << endl;
-            //while (str.right(1) == "\\" && !stream.atEnd()) {
-            //    str.remove(str.length()-1, 1);
-            //    str += stream.readLine();
-            //}
-            if (re.search(str) != -1)
-            {
-                QString tmpTarget=re.cap(1).simplifyWhiteSpace();
-	        kdDebug(9025) << "Adding target: " << tmpTarget << endl;
-                if (m_targets.find(tmpTarget)==m_targets.end())
-                   m_targets += tmpTarget;
-            }
-        }
-        f.close();
+       kdDebug(9025) << "Trying to load a makefile... " << endl;
+
+       m_parsedMakefiles.clear();
+       m_makefilesToParse.clear();
+       m_makefilesToParse.push("Makefile");
+       m_makefilesToParse.push("makefile");
+       while (!m_makefilesToParse.isEmpty())
+          parseMakefile(m_makefilesToParse.pop());
+
         m_targets.sort();
+        m_targetsObjectFiles.sort();
+        m_targetsOtherFiles.sort();
+
     }
 
+    m_targetMenu->insertItem(i18n("Object Files"), m_targetObjectFilesMenu);
+    m_targetMenu->insertItem(i18n("Other Files"), m_targetOtherFilesMenu);
+
     int id = 0;
     QStringList::ConstIterator it;
     for (it = m_targets.begin(); it != m_targets.end(); ++it)
         m_targetMenu->insertItem(*it, id++);
+
+    id = 0;
+    for (it = m_targetsObjectFiles.begin(); it != m_targetsObjectFiles.end(); ++it)
+        m_targetObjectFilesMenu->insertItem(*it, id++);
+
+    id = 0;
+    for (it = m_targetsOtherFiles.begin(); it != m_targetsOtherFiles.end(); ++it)
+        m_targetOtherFilesMenu->insertItem(*it, id++);
 }
 
+void CustomProjectPart::parseMakefile(const QString& filename)
+{
+   if (m_parsedMakefiles.contains(filename))
+      return;
+
+   m_parsedMakefiles.insert(filename, 1);
+
+
+   QString absFilename=filename;
+   if (!filename.startsWith("/"))
+      absFilename=buildDirectory() + "/"+filename;
+
+   QFile f(absFilename);
+   if (!f.open(IO_ReadOnly)) {
+      kdDebug(9025) << "could not open " << absFilename<<endl;
+      return;
+   }
+   QRegExp re("^([^($%.#][^)\\s]+) *:.*$");
+   re.setMinimal(true);
+
+   QRegExp includedMakefilesRe("^include\\s+(\\S+)");
+   QString str = "";
+   while (!f.atEnd()) {
+      f.readLine(str, 200);
+
+      // Read all continuation lines
+      // kdDebug(9025) << "Trying: " << str.simplifyWhiteSpace() << endl;
+      //while (str.right(1) == "\\" && !stream.atEnd()) {
+      //    str.remove(str.length()-1, 1);
+      //    str += stream.readLine();
+      //}
+
+      if (includedMakefilesRe.search(str) != -1)
+      {
+         m_makefilesToParse.push(includedMakefilesRe.cap(1).simplifyWhiteSpace());
+      }
+      else if (re.search(str) != -1)
+      {
+         QString tmpTarget=re.cap(1).simplifyWhiteSpace();
+         if (tmpTarget.endsWith(".o"))
+         {
+            if (m_targetsObjectFiles.find(tmpTarget)==m_targetsObjectFiles.end())
+               m_targetsObjectFiles += tmpTarget;
+         }
+         else if (tmpTarget.contains('.'))
+         {
+            if (m_targetsOtherFiles.find(tmpTarget)==m_targetsOtherFiles.end())
+               m_targetsOtherFiles += tmpTarget;
+         }
+         else
+         {
+            if (m_targets.find(tmpTarget)==m_targets.end())
+               m_targets += tmpTarget;
+         }
+      }
+   }
+   f.close();
+}
 
 void CustomProjectPart::targetMenuActivated(int id)
 {
@@ -762,6 +843,18 @@ void CustomProjectPart::targetMenuActivated(int id)
     startMakeCommand(buildDirectory(), target);
 }
 
+void CustomProjectPart::targetObjectFilesMenuActivated(int id)
+{
+    QString target = m_targetsObjectFiles[id];
+    startMakeCommand(buildDirectory(), target);
+}
+
+void CustomProjectPart::targetOtherFilesMenuActivated(int id)
+{
+    QString target = m_targetsOtherFiles[id];
+    startMakeCommand(buildDirectory(), target);
+}
+
 void CustomProjectPart::updateMakeEnvironmentsMenu()
 {
     QDomDocument &dom = *projectDom();
