@@ -43,13 +43,14 @@
 #include "config.h"
 #include "envvartools.h"
 
+#include <kdevplugininfo.h>
 
 typedef KDevGenericFactory<TrollProjectPart> TrollProjectFactory;
-static const KAboutData data("kdevtrollproject", I18N_NOOP("QMake Manager"), "1.0");
-K_EXPORT_COMPONENT_FACTORY( libkdevtrollproject, TrollProjectFactory( &data ) )
+static const KDevPluginInfo data("kdevtrollproject");
+K_EXPORT_COMPONENT_FACTORY( libkdevtrollproject, TrollProjectFactory( data ) )
 
 TrollProjectPart::TrollProjectPart(QObject *parent, const char *name, const QStringList& args )
-    : KDevProject("TrollProject", "trollproject", parent, name ? name : "TrollProjectPart")
+    : KDevBuildTool(&data, parent, name ? name : "TrollProjectPart")
 {
     setInstance(TrollProjectFactory::instance());
 
@@ -110,7 +111,7 @@ TrollProjectPart::TrollProjectPart(QObject *parent, const char *name, const QStr
                               "in the project settings dialog, <b>Make Options</b> tab."));
 
     action = new KAction( i18n("Execute Main Program"), "exec", SHIFT+Key_F9,
-                          m_widget, SLOT(slotExecuteProject()),
+                          this, SLOT(slotBuildAndExecuteProject()),
                           actionCollection(), "build_execute_project" );
     action->setToolTip(i18n("Execute main program"));
     action->setWhatsThis(i18n("<b>Execute program</b><p>Executes the main program specified in project settings, <b>Run Options</b> tab."));
@@ -147,7 +148,7 @@ TrollProjectPart::TrollProjectPart(QObject *parent, const char *name, const QStr
                               "in the project settings dialog, <b>Make Options</b> tab."));
 
     action = new KAction( i18n("Execute Subproject"), "exec", 0,
-                          m_widget, SLOT(slotExecuteTarget()),
+                          this, SLOT(slotBuildAndExecuteTarget()),
                           actionCollection(), "build_execute_target" );
     action->setToolTip(i18n("Execute subproject"));
     action->setWhatsThis(i18n("<b>Execute subproject</b><p>Executes the target program for the currently selected subproject. "
@@ -219,10 +220,10 @@ QString TrollProjectPart::makeEnvironment()
 void TrollProjectPart::projectConfigWidget(KDialogBase *dlg)
 {
     QVBox *vbox;
-    vbox = dlg->addVBoxPage(i18n("Run Options"));
+    vbox = dlg->addVBoxPage(i18n("Run Options"), i18n("Run Options"), BarIcon( "make", KIcon::SizeMedium ));
     RunOptionsWidget *optdlg = new RunOptionsWidget(*projectDom(), "/kdevtrollproject", buildDirectory(), vbox);
 
-    vbox = dlg->addVBoxPage(i18n("Make Options"));
+    vbox = dlg->addVBoxPage(i18n("Make Options"), i18n("Make Options"), BarIcon( "make", KIcon::SizeMedium ));
     MakeOptionsWidget *w4 = new MakeOptionsWidget(*projectDom(), "/kdevtrollproject", vbox);
     connect( dlg, SIGNAL(okClicked()), w4, SLOT(accept()) );
 
@@ -274,6 +275,26 @@ DomUtil::PairList TrollProjectPart::runEnvironmentVars() const
     return DomUtil::readPairListEntry(*projectDom(), "/kdevtrollproject/run/envvars", "envvar", "name", "value");
 }
 
+void TrollProjectPart::slotBuildAndExecuteProject()
+{
+    partController()->saveAllFiles();
+    if (isDirty()) {
+        m_executeAfterBuild = true;
+        m_widget->slotBuildProject();
+    } else
+        m_widget->slotExecuteProject();
+}
+
+void TrollProjectPart::slotBuildAndExecuteTarget()
+{
+    partController()->saveAllFiles();
+    if (isDirty()) {
+        m_executeAfterBuild = true;
+        m_widget->slotBuildTarget();
+    } else
+        m_widget->slotExecuteTarget();
+}
+
 
 /** Retuns the currently selected run directory
   * The returned string can be:
@@ -495,10 +516,10 @@ void TrollProjectPart::slotCommandFinished( const QString& command )
 {
     Q_UNUSED( command );
 
-    if( m_buildCommand != command )
-        return;
-
-    m_buildCommand = QString::null;
+//     if( m_buildCommand != command )
+//         return;
+// 
+//     m_buildCommand = QString::null;
 
     m_timestamp.clear();
     QStringList fileList = allFiles();
