@@ -1,6 +1,7 @@
+%{H_TEMPLATE}
 
-#ifndef __KDEVPART_$APPNAMEUC$_H__
-#define __KDEVPART_$APPNAMEUC$_H__
+#ifndef __KDEVPART_%{APPNAMEUC}_H__
+#define __KDEVPART_%{APPNAMEUC}_H__
 
 
 #include <kdevelop/kdevplugin.h>
@@ -14,12 +15,12 @@ class KAction;
 /*
  Please read the README.dox file for more info about this part
  */
-class $APPNAME$Part : public KDevLanguageSupport
+class %{APPNAME}Part : public KDevLanguageSupport
 {
 	Q_OBJECT
 	public:
-		$APPNAME$Part(QObject *parent, const char *name, const QStringList &);
-		~$APPNAME$Part();
+		%{APPNAME}Part(QObject *parent, const char *name, const QStringList &);
+		~%{APPNAME}Part();
 	protected:
 		virtual Features features();
 		virtual KMimeType::List mimeTypes();
@@ -29,7 +30,7 @@ class $APPNAME$Part : public KDevLanguageSupport
 		void projectConfigWidget(KDialogBase *dlg);
 		void projectOpened();
 		void projectClosed();
-		void savedFile(const QString &fileName);
+		void savedFile(const KURL &fileName);
 		void addedFilesToProject(const QStringList &fileList);
 		void removedFilesFromProject(const QStringList &fileList);
 		void parse();
