@@ -56,18 +56,21 @@
 
 #include <iostream>
 
+#include <kdevplugininfo.h>
+#include <debugger.h>
+
 #include "debuggerpart.h"
 
 namespace GDBDebugger
 {
 
-static const KAboutData data("kdevdebugger", I18N_NOOP("Debugger"), "1.0");
+static const KDevPluginInfo data("kdevdebugger");
 
 typedef KDevGenericFactory<DebuggerPart> DebuggerFactory;
-K_EXPORT_COMPONENT_FACTORY( libkdevdebugger, DebuggerFactory( &data ) )
+K_EXPORT_COMPONENT_FACTORY( libkdevdebugger, DebuggerFactory( data ) )
 
 DebuggerPart::DebuggerPart( QObject *parent, const char *name, const QStringList & ) :
-    KDevPlugin( "CppDebugger", "debugger", parent, name ? name : "DebuggerPart" ),
+    KDevPlugin( &data, parent, name ? name : "DebuggerPart" ),
     controller(0)
 {
     setObjId("DebuggerInterface");
@@ -75,6 +78,8 @@ DebuggerPart::DebuggerPart( QObject *parent, const char *name, const QStringList
 
     setXMLFile("kdevdebugger.rc");
 
+    m_debugger = new Debugger( partController() );
+    
     statusBarIndicator = new QLabel(" ", mainWindow()->statusBar());
     statusBarIndicator->setFixedWidth(15);
     mainWindow()->statusBar()->addWidget(statusBarIndicator, 0, true);
@@ -82,7 +87,7 @@ DebuggerPart::DebuggerPart( QObject *parent, const char *name, const QStringList
 
     // Setup widgets and dbgcontroller
     variableWidget = new VariableWidget( 0, "variablewidget");
-    variableWidget->setEnabled(false);
+//     /*variableWidget*/->setEnabled(false);
     variableWidget->setIcon(SmallIcon("math_brace"));
     variableWidget->setCaption(i18n("Variable Tree"));
     QWhatsThis::add
@@ -97,7 +102,7 @@ DebuggerPart::DebuggerPart( QObject *parent, const char *name, const QStringList
                               "variable(s) to the watch section.\n"
                               "To change a variable value in your "
                               "running app use a watch variable (&eg; a=5)."));
-    mainWindow()->embedSelectView(variableWidget, i18n("Variables / Watch"), i18n("Debugger variable-view"));
+    mainWindow()->embedSelectView(variableWidget, i18n("Variables"), i18n("Debugger variable-view"));
 //    mainWindow()->setViewAvailable(variableWidget, false);
 
     gdbBreakpointWidget = new GDBBreakpointWidget( 0, "gdbBreakpointWidget" );
@@ -320,7 +325,11 @@ DebuggerPart::DebuggerPart( QObject *parent, const char *name, const QStringList
              appFrontend(), SLOT(insertStderrLine(const QString&)) );
 
     setupController();
+    QTimer::singleShot(0, this, SLOT(setupDcop()));
+}
 
+void DebuggerPart::setupDcop()
+{
     QCStringList objects = kapp->dcopClient()->registeredApplications();
     for (QCStringList::Iterator it = objects.begin(); it != objects.end(); ++it)
         if ((*it).find("drkonqi-") == 0)
@@ -476,7 +485,7 @@ void DebuggerPart::contextWatch()
 
 void DebuggerPart::projectConfigWidget(KDialogBase *dlg)
 {
-	QVBox *vbox = dlg->addVBoxPage(i18n("Debugger"), i18n("Debugger"), BarIcon( icon(), KIcon::SizeMedium) );
+	QVBox *vbox = dlg->addVBoxPage(i18n("Debugger"), i18n("Debugger"), BarIcon( info()->icon(), KIcon::SizeMedium) );
     DebuggerConfigWidget *w = new DebuggerConfigWidget(this, vbox, "debugger config widget");
     connect( dlg, SIGNAL(okClicked()), w, SLOT(accept()) );
     connect( dlg, SIGNAL(finished()), controller, SLOT(configure()) );
@@ -544,6 +553,8 @@ void DebuggerPart::setupController()
              this,                  SLOT(slotStatus(const QString&, int)));
     connect( controller,            SIGNAL(showStepInSource(const QString&, int, const QString&)),
              this,                  SLOT(slotShowStep(const QString&, int)));
+    connect( controller,            SIGNAL(debuggerRunError(int)),
+	     this,                  SLOT(errRunningDebugger(int)));
 
     // controller -> procLineMaker
     connect( controller,            SIGNAL(ttyStdout(const char*)),
@@ -578,7 +589,7 @@ bool DebuggerPart::startDebugger()
         run_envvars   = project()->runEnvironmentVars();
         run_directory = project()->runDirectory();
         program       = project()->mainProgram();
-        run_arguments = project()->runArguments();
+        run_arguments = DomUtil::readEntry(*projectDom(), "/kdevdebugger/general/programargs");
     }
 
     QString shell = DomUtil::readEntry(*projectDom(), "/kdevdebugger/general/dbgshell");
@@ -607,7 +618,7 @@ bool DebuggerPart::startDebugger()
     KActionCollection *ac = actionCollection();
     ac->action("debug_run")->setText( i18n("&Continue") );
 //    ac->action("debug_run")->setIcon( "dbgrun" );
-    ac->action("debug_run")->setStatusText( i18n("Continues the application execution") );
+    ac->action("debug_run")->setToolTip( i18n("Continues the application execution") );
     ac->action("debug_run")->setWhatsThis( i18n("Continue application execution\n\n"
                                            "Continues the execution of your application in the "
                                            "debugger. This only takes effect when the application "
@@ -620,14 +631,14 @@ bool DebuggerPart::startDebugger()
     mainWindow()->setViewAvailable(disassembleWidget, true);
     mainWindow()->setViewAvailable(gdbOutputWidget, true);
 
-    variableWidget->setEnabled(true);
+//     variableWidget->setEnabled(true);
     framestackWidget->setEnabled(true);
     disassembleWidget->setEnabled(true);
 
     gdbOutputWidget->clear();
     gdbOutputWidget->setEnabled(true);
 
-    if (DomUtil::readBoolEntry(*projectDom(), "/kdevdebugger/general/floatingtoolbar", true))
+    if (DomUtil::readBoolEntry(*projectDom(), "/kdevdebugger/general/floatingtoolbar", false))
     {
         floatingToolBar = new DbgToolBar(this, mainWindow()->main());
         floatingToolBar->show();
@@ -651,7 +662,7 @@ void DebuggerPart::slotStopDebugger()
     disassembleWidget->clear();
     disassembleWidget->slotActivate(false);
 
-    variableWidget->setEnabled(false);
+//     variableWidget->setEnabled(false);
     framestackWidget->setEnabled(false);
     disassembleWidget->setEnabled(false);
     gdbOutputWidget->setEnabled(false);
@@ -664,7 +675,7 @@ void DebuggerPart::slotStopDebugger()
     KActionCollection *ac = actionCollection();
     ac->action("debug_run")->setText( i18n("&Start") );
 //    ac->action("debug_run")->setIcon( "1rightarrow" );
-    ac->action("debug_run")->setStatusText( i18n("Runs the program in the debugger") );
+    ac->action("debug_run")->setToolTip( i18n("Runs the program in the debugger") );
     ac->action("debug_run")->setWhatsThis( i18n("Start in debugger\n\n"
                                            "Starts the debugger with the project's main "
                                            "executable. You may set some breakpoints "
@@ -677,6 +688,16 @@ void DebuggerPart::slotStopDebugger()
     core()->running(this, false);
 }
 
+void DebuggerPart::errRunningDebugger(int errorCode)
+{
+  if (errorCode == 127)
+  {
+    KMessageBox::error(mainWindow()->main(), i18n("GDB could not be found. Please make sure it is installed"
+                                     " and in the path and try again"), i18n("Debugger Not Found"));
+  }
+  slotStopDebugger();
+}
+
 void DebuggerPart::projectClosed()
 {
     slotStopDebugger();
@@ -695,7 +716,7 @@ void DebuggerPart::slotRun()
     {
         KActionCollection *ac = actionCollection();
         ac->action("debug_run")->setText( i18n("&Continue") );
-        ac->action("debug_run")->setStatusText( i18n("Continues the application execution") );
+        ac->action("debug_run")->setToolTip( i18n("Continues the application execution") );
         ac->action("debug_run")->setWhatsThis( i18n("Continue application execution\n\n"
             "Continues the execution of your application in the "
             "debugger. This only takes effect when the application "
@@ -869,12 +890,11 @@ void DebuggerPart::slotStatus(const QString &msg, int state)
         stateIndicator = "E";
         stateChanged( QString("stopped") );
         KActionCollection *ac = actionCollection();
-        ac->action("debug_run")->setText( i18n("Restart") );
-//        ac->action("debug_run")->setIcon( "1rightarrow" );
-        ac->action("debug_run")->setStatusText( i18n("Restart the program in the debugger") );
+        ac->action("debug_run")->setText( i18n("To start something","Start") );
+        ac->action("debug_run")->setToolTip( i18n("Restart the program in the debugger") );
         ac->action("debug_run")->setWhatsThis( i18n("Restart in debugger\n\n"
                                            "Restarts the program in the debugger") );
-//        slotStop();
+        slotStop();
     }
     else
     {
@@ -937,4 +957,14 @@ void DebuggerPart::savePartialProjectSession(QDomElement* el)
 
 }
 
+KDevAppFrontend * GDBDebugger::DebuggerPart::appFrontend( )
+{
+    return extension<KDevAppFrontend>("KDevelop/AppFrontend");
+}
+
+KDevDebugger * GDBDebugger::DebuggerPart::debugger()
+{
+    return m_debugger;
+}
+
 #include "debuggerpart.moc"
