@@ -15,6 +15,7 @@
 
 #include "variablewidget.h"
 #include "gdbparser.h"
+#include "gdbcommand.h"
 
 #include <kdebug.h>
 #include <kpopupmenu.h>
@@ -56,6 +57,8 @@ VariableWidget::VariableWidget(QWidget *parent, const char *name)
 //    watchVarEntry_ = new KLineEdit(this);
 
     QPushButton *addButton = new QPushButton(i18n("&Add"), watchEntry );
+    addButton->adjustSize();
+    addButton->setFixedWidth(addButton->width());
 
     QBoxLayout * vbox = new QVBoxLayout();
 
@@ -76,6 +79,7 @@ VariableWidget::VariableWidget(QWidget *parent, const char *name)
     connect( addButton, SIGNAL(clicked()), SLOT(slotAddWatchVariable()) );
     connect( watchVarEditor_, SIGNAL(returnPressed()), SLOT(slotAddWatchVariable()) );
 //    connect( watchVarEntry_, SIGNAL(returnPressed()), SLOT(slotAddWatchVariable()) );
+
 }
 
 // **************************************************************************
@@ -130,6 +134,14 @@ void VariableWidget::slotAddWatchVariable(const QString &ident)
     }
 }
 
+// **************************************************************************
+
+void VariableWidget::focusInEvent(QFocusEvent */*e*/)
+{
+    varTree_->setFocus();
+}
+
+
 // **************************************************************************
 // **************************************************************************
 // **************************************************************************
@@ -146,12 +158,13 @@ VariableTree::VariableTree(VariableWidget *parent, const char *name)
     setSorting(-1);
     QListView::setSelectionMode(QListView::Single);
 
-    addColumn(i18n("Variable"));
-    addColumn(i18n("Value"));
-    addColumn(i18n("Type"));
+    addColumn(i18n("Variable"), 100 );
+    addColumn(i18n("Value"), 100 );
+    addColumn(i18n("Type"), 100 );
 
     connect( this, SIGNAL(contextMenu(KListView*, QListViewItem*, const QPoint&)),
              SLOT(slotContextMenu(KListView*, QListViewItem*)) );
+    connect( this, SIGNAL(toggleRadix(QListViewItem*)), SLOT(slotToggleRadix(QListViewItem*)) );
 
 /*
     work in progress - disabled for now
@@ -185,11 +198,14 @@ void VariableTree::slotContextMenu(KListView *, QListViewItem *item)
             idRemoveWatch = popup.insertItem( i18n("Remove Watch Variable") );
 
         int idToggleWatch = popup.insertItem( i18n("Toggle Watchpoint") );
+        int idToggleRadix = popup.insertItem( i18n("Toggle Hex/Decimal") );
         int	idCopyToClipboard = popup.insertItem( i18n("Copy to Clipboard") );
         int res = popup.exec(QCursor::pos());
 
         if (res == idRemoveWatch)
             delete item;
+        if (res == idToggleRadix)
+            emit toggleRadix(item);
         else if (res == idCopyToClipboard)
         {
             QClipboard *qb = KApplication::clipboard();
@@ -376,6 +392,48 @@ void VariableTree::maybeTip(const QPoint &p)
     }
 }
 
+/* rgruber:
+ * this it the slot which is connected to the toggleRadix() signal
+ * it removes the given watch variable an replaces it by another
+ * watch that includes a format modifier
+ */
+void VariableTree::slotToggleRadix(QListViewItem * item)
+{
+  if (item==NULL)  //no item->nothing to do
+    return;
+
+  VarItem *pOldItem = dynamic_cast<VarItem*>(item);
+  VarItem *pNewItem = NULL;
+
+  QString strName = pOldItem->text(VarNameCol);
+
+  QString strTmp = strName.left(3).lower();
+  if (iOutRadix == 10) {
+      if (strTmp == "/d ")   //is there a wrong format modifier...
+          strName = "/x "+strName.right(strName.length()-3);  //...replace the modifier
+      else if (strTmp == "/x ")
+          strName = strName.right(strName.length()-3);  //stripe the modifier
+      else
+          strName = QString("/x ")+strName;  //add the hex-formater
+  } else
+  if (iOutRadix == 16) {
+      if (strTmp == "/x ")   //is there a wrong format modifier...
+          strName = "/d "+strName.right(strName.length()-3);  //...replace the modifier
+      else if (strTmp == "/d ")   //is there a format modifier?
+          strName = strName.right(strName.length()-3);  //stripe the modifier
+      else
+          strName = QString("/d ")+strName;  //add the dec-formater
+  }
+
+  pNewItem = new VarItem((TrimmableItem *) item->parent(), strName, typeUnknown);
+  emit expandItem(pNewItem);
+
+  pNewItem->moveItem(pOldItem);  //move the new item up right under the old one
+
+  delete item;  //remove the old one so that is seam as if it was replaced by the new item
+  pOldItem=NULL;
+}
+
 // **************************************************************************
 // **************************************************************************
 // **************************************************************************
@@ -451,13 +509,37 @@ QListViewItem *TrimmableItem::lastChild() const
 TrimmableItem *TrimmableItem::findMatch(const QString &match, DataType type) const
 {
     QListViewItem *child = firstChild();
+    bool bRenew=false;  //this indicates if the current item needs to be replaced by a new one.
+   			//the problem is, that the debugger always replaces already
+			//format-modified local item with non-mofified ones. So with every
+			//run we need to newly modify the outcome of the debugger
+
+    int iOutRad = ((VariableTree*)listView())->iOutRadix; //local copy of the output radix
 
     // Check the siblings on this branch
     while (child) {
-        if (child->text(VarNameCol) == match) {
+        QString strMatch = child->text(VarNameCol);
+        bRenew=false;
+	if (strMatch.left(3) == "/x " || strMatch.left(3) == "/d ") {  //is the current item format modified?
+	    strMatch = strMatch.right(strMatch.length()-3);
+	    bRenew=true;
+	}
+	if (strMatch == match) {
             if (TrimmableItem *item = dynamic_cast<TrimmableItem*> (child))
-                if (item->getDataType() == type)
-                    return item;
+                if ( item->getDataType() == type ||
+		     ( iOutRad==16 && item->getDataType() == typeValue ) ||
+		     ( iOutRad==10 && item->getDataType() == typePointer ) ) {
+		    if (bRenew && dynamic_cast<VarItem*>(item)) { //do we need to replace?
+			VarItem* pNewItem = new VarItem((TrimmableItem *) item->parent(),
+				 child->text(VarNameCol), typeUnknown);
+			emit ((VariableTree*)pNewItem->listView())->expandItem(pNewItem);
+			pNewItem->moveItem(item);
+			delete item;
+			item=NULL;
+			item=pNewItem;
+		    }
+		    return item;
+		}
         }
 
         child = child->nextSibling();
@@ -592,6 +674,8 @@ QString VarItem::fullName() const
 
 void VarItem::setText(int column, const QString &data)
 {
+    QString strData=data;
+
     if (!isActive() && isOpen() && dataType_ == typePointer) {
         waitingForData();
         ((VariableTree*)listView())->expandItem(this);
@@ -604,7 +688,7 @@ void VarItem::setText(int column, const QString &data)
             highlight_ = (oldValue != QString(data));
     }
 
-    QListViewItem::setText(column, data);
+    QListViewItem::setText(column, strData);
     repaint();
 }
 
@@ -619,6 +703,14 @@ void VarItem::updateValue(char *buf)
         (strncmp(buf, "There is no member or method named len.", 39) == 0))
         return;
 
+    if (strncmp(buf, "Cannot access memory at address", 31) == 0 &&
+        dataType_ == typePointer &&  //only if it is a pointer...
+        ((VariableTree*)listView())->iOutRadix == 16) { //...and only do if outputradix is set to hex
+	dataType_ = typeValue;
+	((VariableTree*)listView())->expandItem(this);
+	return;
+    }
+
     if (*buf == '$') {
         if (char *end = strchr(buf, '='))
             buf = end+2;
@@ -917,4 +1009,6 @@ void WatchRoot::requestWatchVars()
 
 }
 
+
 #include "variablewidget.moc"
+
