@@ -35,6 +35,7 @@
 #include "kdevcore.h"
 #include "kdevproject.h"
 #include "kdevpartcontroller.h"
+#include "kdevplugininfo.h"
 #include "kdevappfrontend.h"
 //#include "classstore.h"
 //#include "parsedclass.h"
@@ -44,11 +45,11 @@
 //#include "programmingbycontract.h"
 
 typedef KDevGenericFactory<PerlSupportPart> PerlSupportFactory;
-static const KAboutData data("kdevperlsupport", I18N_NOOP("Language"), "1.0");
-K_EXPORT_COMPONENT_FACTORY( libkdevperlsupport, PerlSupportFactory( &data ) )
+static const KDevPluginInfo data("kdevperlsupport");
+K_EXPORT_COMPONENT_FACTORY( libkdevperlsupport, PerlSupportFactory( data ) )
 
 PerlSupportPart::PerlSupportPart(QObject *parent, const char *name, const QStringList &)
-    : KDevLanguageSupport("PerlSupport", "perl", parent, name ? name : "PerlSupportPart")
+    : KDevLanguageSupport(&data, parent, name ? name : "PerlSupportPart")
 {
     setInstance(PerlSupportFactory::instance());
 
@@ -61,30 +62,30 @@ PerlSupportPart::PerlSupportPart(QObject *parent, const char *name, const QStrin
 
     KAction *action;
 
-    action = new KAction( i18n("Execute Program"), "exec", 0,
+    action = new KAction( i18n("Execute Main Program"), "exec", 0,
                           this, SLOT(slotExecute()),
                           actionCollection(), "build_exec" );
-    action->setStatusText( i18n("Runs the Perl program") );
+    action->setToolTip( i18n("Runs the Perl program") );
 
     action = new KAction( i18n("Execute String..."), "exec", 0,
                           this, SLOT(slotExecuteString()),
                           actionCollection(), "build_execstring" );
-    action->setStatusText( i18n("Executes a string as Perl code") );
+    action->setToolTip( i18n("Executes a string as Perl code") );
 
     action = new KAction( i18n("Start Perl Interpreter"), "exec", 0,
                           this, SLOT(slotStartInterpreter()),
                           actionCollection(), "build_runinterpreter" );
-    action->setStatusText( i18n("Starts the Perl interpreter without a program") );
+    action->setToolTip( i18n("Starts the Perl interpreter without a program") );
 
     action = new KAction( i18n("Find Perl Function Documentation..."), 0,
                           this, SLOT(slotPerldocFunction()),
                           actionCollection(), "help_perldocfunction" );
-    action->setStatusText( i18n("Show the documentation page of a Perl function") );
+    action->setToolTip( i18n("Show the documentation page of a Perl function") );
 
     action = new KAction( i18n("Find Perl FAQ Entry..."), 0,
                           this, SLOT(slotPerldocFAQ()),
                           actionCollection(), "help_perldocfaq" );
-    action->setStatusText( i18n("Show the FAQ entry for a keyword") );
+    action->setToolTip( i18n("Show the FAQ entry for a keyword") );
 
     //perl parser for codemodel
     m_parser = new  perlparser(core(),codeModel(),interpreter());
@@ -175,7 +176,7 @@ void PerlSupportPart::savedFile(const KURL &fileName)
 
 KDevLanguageSupport::Features PerlSupportPart::features()
 {
-    return KDevLanguageSupport::Features(Classes | Functions | Variables | Namespaces | Scripts | NewClass | AddMethod | AddAttribute | NewScript);
+    return KDevLanguageSupport::Features(Classes | Functions | Variables | Namespaces | /*Scripts | */NewClass | AddMethod | AddAttribute /*| NewScript*/);
 //    return Functions;
 }
 
@@ -192,7 +193,8 @@ QString PerlSupportPart::interpreter()
 void PerlSupportPart::startApplication(const QString &program)
 {
     bool inTerminal = DomUtil::readBoolEntry(*projectDom(), "/kdevperlsupport/run/terminal");
-    appFrontend()->startAppCommand(QString::QString(), program, inTerminal);
+    if (KDevAppFrontend *appFrontend = extension<KDevAppFrontend>("KDevelop/AppFrontend"))
+        appFrontend->startAppCommand(QString::QString(), program, inTerminal);
 }
 
 
