@@ -40,6 +40,7 @@
 #include <kdevpartcontroller.h>
 #include <codemodel.h>
 #include <domutil.h>
+#include <kdevplugininfo.h>
 
 #include "phpconfigdata.h"
 #include "phpconfigwidget.h"
@@ -55,11 +56,11 @@
 
 using namespace std;
 
-static const KAboutData data("kdevphpsupport", I18N_NOOP("Language"), "1.0");
-K_EXPORT_COMPONENT_FACTORY( libkdevphpsupport, PHPSupportFactory( &data ) )
+static const KDevPluginInfo data("kdevphpsupport");
+K_EXPORT_COMPONENT_FACTORY( libkdevphpsupport, PHPSupportFactory( data ) )
 
 PHPSupportPart::PHPSupportPart(QObject *parent, const char *name, const QStringList &)
-    : KDevLanguageSupport("PHPSupport", "php", parent, name ? name : "PHPSupportPart")
+    : KDevLanguageSupport(&data, parent, name ? name : "PHPSupportPart")
 {
   m_htmlView=0;
   phpExeProc=0;
@@ -114,6 +115,9 @@ PHPSupportPart::PHPSupportPart(QObject *parent, const char *name, const QStringL
   m_parser = new  PHPParser(core(),codeModel());
   m_codeCompletion = new  PHPCodeCompletion(configData, core(),codeModel());
 
+  new KAction(i18n("Complete Text"), CTRL+Key_Space, m_codeCompletion, SLOT(cursorPositionChanged()),
+	actionCollection(), "edit_complete_text");
+  
   connect(partController(), SIGNAL(activePartChanged(KParts::Part*)),
 	  this, SLOT(slotActivePartChanged(KParts::Part *)));
 }
@@ -249,7 +253,8 @@ bool PHPSupportPart::validateConfig(){
 void PHPSupportPart::executeOnWebserver(){
 
   // Save all files once
-  partController()->saveAllFiles();
+  if (partController()->saveAllFiles()==false)
+       return; //user cancelled
   
   // Figure out the name of the remote file
   QString file;
