@@ -28,6 +28,8 @@ public:
   RubySupportPart(QObject *parent, const char *name, const QStringList &);
   virtual ~RubySupportPart();
 
+  virtual KDevDesignerIntegration *designer(KInterfaceDesigner::DesignerType type);
+  
 protected:
     virtual Features features();
     virtual KMimeType::List mimeTypes();
@@ -35,19 +37,30 @@ protected:
 private slots:
     void projectConfigWidget(KDialogBase *dlg);
     void projectOpened();
+    void projectClosed();
     void savedFile(const KURL &fileName);
     void addedFilesToProject(const QStringList &fileList);
     void removedFilesFromProject(const QStringList &fileList);
     void slotRun();
+    void slotCreateSubclass();
+    void contextMenu(QPopupMenu *popup, const Context *context);
 
     void initialParse();
 
 private:
     void startApplication(const QString &program);
     QString interpreter();
+    QString mainProgram();
+    QString programArgs();
+    QString characterCoding();
 
     void maybeParse(const QString fileName);
     void parse(const QString &fileName);
+
+    QMap<KInterfaceDesigner::DesignerType, KDevDesignerIntegration*> m_designers;
+    
+    QString m_contextFileName;
+
 };
 
 
