@@ -15,6 +15,7 @@
 #include <kbuttonbox.h>
 #include <klocale.h>
 #include <kstdguiitem.h>
+#include <kdeversion.h>
 
 #include "addfilegroupdlg.h"
 
@@ -49,8 +50,14 @@ AddFileGroupDialog::AddFileGroupDialog(const QString& old_title, const QString&
 
     KButtonBox *buttonbox = new KButtonBox(this);
     buttonbox->addStretch();
+#if KDE_IS_VERSION( 3, 2, 90 )
+    m_pOk = buttonbox->addButton(KStdGuiItem::ok());
+    QPushButton *cancel = buttonbox->addButton(KStdGuiItem::cancel());
+#else
     m_pOk = buttonbox->addButton(KStdGuiItem::ok().text());
     QPushButton *cancel = buttonbox->addButton(KStdGuiItem::cancel().text());
+#endif
+
     m_pOk->setDefault(true);
     connect( m_pOk, SIGNAL(clicked()), this, SLOT(accept()) );
     connect( cancel, SIGNAL(clicked()), this, SLOT(reject()) );
