@@ -28,20 +28,20 @@
 #include <kpopupmenu.h>
 #include <qregexp.h>
 #include <qinputdialog.h>
-#include <qlayout.h>
 #include <qlabel.h>
 #include <qcheckbox.h>
 #include <qwhatsthis.h>
-#include <kdebug.h>
 #include <qdragobject.h>
+#include <qtimer.h>
+#include <kcombobox.h>
+#include <kdeversion.h>
 
 #include <kdevcore.h>
-#include "kdevcore.h"
 #include <kdevproject.h>
 #include <kdevpartcontroller.h>
 
-#include <snippetdlg.h>
-#include <snippetitem.h>
+#include "snippetdlg.h"
+#include "snippetitem.h"
 
 #include "snippet_part.h"
 #include "snippet_widget.h"
@@ -50,9 +50,6 @@ SnippetWidget::SnippetWidget(SnippetPart *part)
 		: KListView(0, "snippet widget"), QToolTip( viewport() ),
 		m_part( part )
 {
-
-    m_dialog = new SnippetDlg(this, "SnippetDlg", true);
-
     // init the QPtrList
     _list.setAutoDelete(TRUE);
 
@@ -64,6 +61,7 @@ SnippetWidget::SnippetWidget(SnippetPart *part)
     setAcceptDrops(true);
     setDragEnabled(false);
     setDropVisualizer(false);
+    setRootIsDecorated(true);
 
     //connect the signals
     connect( this, SIGNAL( contextMenuRequested ( QListViewItem *, const QPoint & , int ) ),
@@ -74,14 +72,24 @@ SnippetWidget::SnippetWidget(SnippetPart *part)
              this, SLOT( slotDropped(QDropEvent *, QListViewItem *) ) );
 
     _cfg = NULL;
-    initConfig();
+
+    QTimer::singleShot(0, this, SLOT(initConfig()));
 }
 
 SnippetWidget::~SnippetWidget()
 {
   writeConfig();
+  delete _cfg;
 
-  _list.clear();
+  /* We need to delete the child items before the parent items
+     otherwise KDevelop would crash on exiting */
+  SnippetItem * item;
+  while (_list.count() > 0) {
+    for (item=_list.first(); item; item=_list.next()) {
+      if (item->childCount() == 0)
+          _list.remove(item);
+    }
+  }
 }
 
 
@@ -91,12 +99,49 @@ SnippetWidget::~SnippetWidget()
  */
 void SnippetWidget::slotAdd()
 {
-  kdDebug(26) << "Ender slotAdd()" << endl;
-  m_dialog->snippetName->clear();
-  m_dialog->snippetText->clear();
+  kdDebug(9035) << "Ender slotAdd()" << endl;
+  SnippetDlg dlg(this, "SnippetDlg", true);
 
-  if (m_dialog->exec() == QDialog::Accepted) {
-    _list.append( new SnippetItem(this, m_dialog->snippetName->text(), m_dialog->snippetText->text()) );
+  /*check if the user clicked a SnippetGroup
+    If not, we set the group variable to the SnippetGroup
+    which the selected item is a child of*/
+  SnippetGroup * group = dynamic_cast<SnippetGroup*>(selectedItem());
+  if (!group)
+    group = dynamic_cast<SnippetGroup*>(selectedItem()->parent());
+
+  /*fill the combobox with the names of all SnippetGroup entries*/
+  for (SnippetItem *it=_list.first(); it; it=_list.next()) {
+    if (dynamic_cast<SnippetGroup*>(it)) {
+      dlg.cbGroup->insertItem(it->getName());
+    }
+  }
+  dlg.cbGroup->setCurrentText(group->getName());
+
+  if (dlg.exec() == QDialog::Accepted) {
+      group = dynamic_cast<SnippetGroup*>(SnippetItem::findItemByName(dlg.cbGroup->currentText(), _list));
+      _list.append( new SnippetItem(group, dlg.snippetName->text(), dlg.snippetText->text()) );
+  }
+}
+
+
+/*!
+    \fn SnippetWidget::slotAddGroup()
+    Opens the didalog to add a snippet
+ */
+void SnippetWidget::slotAddGroup()
+{
+  kdDebug(9035) << "Ender slotAddGroup()" << endl;
+  SnippetDlg dlg(this, "SnippetDlg", true);
+  dlg.snippetText->setEnabled(false);
+  dlg.snippetText->setText("GROUP");
+  dlg.setCaption(i18n("Add Group"));
+  dlg.cbGroup->insertItem(i18n("All"));
+  dlg.cbGroup->insertStringList(m_part->getAllLanguages());
+  dlg.cbGroup->setCurrentText(i18n("All"));
+  dlg.textLabelGroup->setText(i18n("Language:"));
+
+  if (dlg.exec() == QDialog::Accepted) {
+    _list.append( new SnippetGroup(this, dlg.snippetName->text(), SnippetGroup::getMaxId(), dlg.cbGroup->currentText()) );
   }
 }
 
@@ -109,12 +154,34 @@ void SnippetWidget::slotRemove()
 {
   //get current data
   QListViewItem * item = currentItem();
-  SnippetItem *pSnippet = dynamic_cast<SnippetItem*>( item );
-  if (!pSnippet)
+  SnippetItem *snip = dynamic_cast<SnippetItem*>( item );
+  SnippetGroup *group = dynamic_cast<SnippetGroup*>( item );
+  if (!snip)
     return;
 
-  removeItem(item);
-  _list.remove(pSnippet);
+  if (group) {
+    if (group->childCount() > 0 &&
+#if KDE_VERSION >= KDE_MAKE_VERSION(3,3,0)
+        KMessageBox::warningContinueCancel(this, i18n("Do you really want to remove this group and all its snippets?"),QString::null,KStdGuiItem::del())
+        == KMessageBox::Cancel)
+#else
+        KMessageBox::warningContinueCancel(this, i18n("Do you really want to remove this group and all its snippets?"),
+		QString::null,KGuiItem( "&Delete", "editdelete",
+                   "Delete item(s)"))
+        == KMessageBox::Cancel)
+#endif
+      return;
+
+    for (SnippetItem *it=_list.first(); it; it=_list.next()) {
+      if (it->getParent() == group->getId()) {
+        kdDebug(9035) << "remove " << it->getName() << endl;
+        _list.remove(it);
+      }
+    }
+  }
+
+  kdDebug(9035) << "remove " << snip->getName() << endl;
+  _list.remove(snip);
 }
 
 
@@ -128,27 +195,78 @@ void SnippetWidget::slotEdit()
   //get current data
   QListViewItem * item = currentItem();
 
+  SnippetGroup *pGroup = dynamic_cast<SnippetGroup*>(item);
   SnippetItem *pSnippet = dynamic_cast<SnippetItem*>( item );
-  if (!pSnippet)
+  if (!pSnippet || pGroup) /*selected item must be a SnippetItem but MUST not be a SnippetGroup*/
     return;
 
   //init the dialog
-  m_dialog->snippetName->setText(pSnippet->getName());
-  m_dialog->snippetText->setText(pSnippet->getText());
-  m_dialog->btnAdd->setText(i18n("&Apply"));
+  SnippetDlg dlg(this, "SnippetDlg", true);
+  dlg.snippetName->setText(pSnippet->getName());
+  dlg.snippetText->setText(pSnippet->getText());
+  dlg.btnAdd->setText(i18n("&Apply"));
 
-  if (m_dialog->exec() == QDialog::Accepted) {
+  dlg.setCaption(i18n("Edit Snippet"));
+  /*fill the combobox with the names of all SnippetGroup entries*/
+  for (SnippetItem *it=_list.first(); it; it=_list.next()) {
+    if (dynamic_cast<SnippetGroup*>(it)) {
+      dlg.cbGroup->insertItem(it->getName());
+    }
+  }
+  dlg.cbGroup->setCurrentText(SnippetItem::findGroupById(pSnippet->getParent(), _list)->getName());
+
+  if (dlg.exec() == QDialog::Accepted) {
     //update the KListView and the SnippetItem
-    item->setText( 0, m_dialog->snippetName->text() );
-    pSnippet->setName( m_dialog->snippetName->text() );
-    pSnippet->setText( m_dialog->snippetText->text() );
+    item->setText( 0, dlg.snippetName->text() );
+    pSnippet->setName( dlg.snippetName->text() );
+    pSnippet->setText( dlg.snippetText->text() );
+
+    /* if the user changed the parent we need to move the snippet */
+    if ( SnippetItem::findGroupById(pSnippet->getParent(), _list)->getName() != dlg.cbGroup->currentText() ) {
+      SnippetGroup * newGroup = dynamic_cast<SnippetGroup*>(SnippetItem::findItemByName(dlg.cbGroup->currentText(), _list));
+      pSnippet->parent()->takeItem(pSnippet);
+      newGroup->insertItem(pSnippet);
+      pSnippet->resetParent();
+    }
 
     setSelected(item, TRUE);
   }
-
-  m_dialog->btnAdd->setText(i18n("Add"));
 }
 
+/*!
+    \fn SnippetWidget::slotEditGroup()
+    Opens the dialog of editing the selected snippet-group
+ */
+void SnippetWidget::slotEditGroup()
+{
+  //get current data
+  QListViewItem * item = currentItem();
+
+  SnippetGroup *pGroup = dynamic_cast<SnippetGroup*>( item );
+  if (!pGroup) /*selected item MUST be a SnippetGroup*/
+    return;
+
+  //init the dialog
+  SnippetDlg dlg(this, "SnippetDlg", true);
+  dlg.snippetName->setText(pGroup->getName());
+  dlg.snippetText->setText(pGroup->getText());
+  dlg.btnAdd->setText(i18n("&Apply"));
+  dlg.snippetText->setEnabled(FALSE);
+  dlg.setCaption(i18n("Edit Group"));
+  dlg.cbGroup->insertItem(i18n("All"));
+  dlg.cbGroup->insertStringList(m_part->getAllLanguages());
+  dlg.cbGroup->setCurrentText(pGroup->getLanguage());
+  dlg.textLabelGroup->setText(i18n("Language:"));
+
+  if (dlg.exec() == QDialog::Accepted) {
+    //update the KListView and the SnippetGroup
+    item->setText( 0, dlg.snippetName->text() );
+    pGroup->setName( dlg.snippetName->text() );
+    pGroup->setLanguage(dlg.cbGroup->currentText());
+
+    setSelected(item, TRUE);
+  }
+}
 
 //  \fn SnippetWidget::slotListDblClicked()
 /*!
@@ -158,7 +276,7 @@ void SnippetWidget::slotEdit()
 void SnippetWidget::slotListDblClicked(QListViewItem * item, const QPoint &, int)
 {
   SnippetItem *pSnippet = dynamic_cast<SnippetItem*>( item );
-  if (!pSnippet)
+  if (!pSnippet || dynamic_cast<SnippetGroup*>(item))
       return;
 
   //process variables if any, then insert into the active view
@@ -202,22 +320,45 @@ void SnippetWidget::writeConfig()
                                      //they get overwritten by a more recent entry
   _cfg->setGroup("SnippetPart");
 
-  _cfg->writeEntry("snippetCount", _list.count());
   SnippetItem *item;
   QString strKeyName="";
   QString strKeyText="";
-  int iCount = 1;
+  QString strKeyId="";
+
+  int iSnipCount = 0;
+  int iGroupCount = 0;
+
   for ( item = _list.first(); item; item = _list.next() ) {  //write the snippet-list
-    strKeyName=QString("snippetName_%1").arg(iCount);
-    strKeyText=QString("snippetText_%1").arg(iCount);
+    kdDebug(9035) << "SnippetWidget::writeConfig() " << item->getName() << endl;
+    SnippetGroup * group = dynamic_cast<SnippetGroup*>(item);
+    if (group) {
+      kdDebug(9035) << "-->GROUP " << item->getName() << group->getId() << " " << iGroupCount<< endl;
+      strKeyName=QString("snippetGroupName_%1").arg(iGroupCount);
+      strKeyId=QString("snippetGroupId_%1").arg(iGroupCount);
+      strKeyText=QString("snippetGroupLang_%1").arg(iGroupCount);
 
-    _cfg->writeEntry(strKeyName, item->getName());
-    _cfg->writeEntry(strKeyText, item->getText());
+      _cfg->writeEntry(strKeyName, group->getName());
+      _cfg->writeEntry(strKeyId, group->getId());
+      _cfg->writeEntry(strKeyText, group->getLanguage());
+      iGroupCount++;
+    } else if (dynamic_cast<SnippetItem*>(item)) {
+      kdDebug(9035) << "-->ITEM " << item->getName() << item->getParent() << " " << iSnipCount << endl;
+      strKeyName=QString("snippetName_%1").arg(iSnipCount);
+      strKeyText=QString("snippetText_%1").arg(iSnipCount);
+      strKeyId=QString("snippetParent_%1").arg(iSnipCount);
 
-    iCount++;
+      _cfg->writeEntry(strKeyName, item->getName());
+      _cfg->writeEntry(strKeyText, item->getText());
+      _cfg->writeEntry(strKeyId, item->getParent());
+      iSnipCount++;
+    } else {
+      kdDebug(9035) << "-->ERROR " << item->getName() << endl;
+    }
   }
+  _cfg->writeEntry("snippetCount", iSnipCount);
+  _cfg->writeEntry("snippetGroupCount", iGroupCount);
 
-  iCount = 1;
+  int iCount = 1;
   QMap<QString, QString>::Iterator it;
   for ( it = _mapSaved.begin(); it != _mapSaved.end(); ++it ) {  //write the saved variable values
     if (it.data().length()<=0) continue;  //is the saved value has no length -> no need to save it
@@ -236,6 +377,7 @@ void SnippetWidget::writeConfig()
   _cfg->writeEntry( "snippetDelimiter", _SnippetConfig.getDelimiter() );
   _cfg->writeEntry( "snippetVarInput", _SnippetConfig.getInputMethod() );
   _cfg->writeEntry( "snippetToolTips", _SnippetConfig.useToolTips() );
+  _cfg->writeEntry( "snippetGroupAutoOpen", _SnippetConfig.getAutoOpenGroups() );
 
   _cfg->writeEntry("snippetSingleRect", _SnippetConfig.getSingleRect() );
   _cfg->writeEntry("snippetMultiRect", _SnippetConfig.getMultiRect() );
@@ -244,6 +386,37 @@ void SnippetWidget::writeConfig()
 }
 
 
+/*!
+    This function was introduced together with the grouping-feature.
+    As far as some guys might have some snippets stored in the "old" way
+    we need to create a "DEFAULT" group into which we can import all snippets
+ */
+void SnippetWidget::initConfigOldVersion(KConfig *cfg)
+{
+  SnippetGroup * group = new SnippetGroup(this, "DEFAULT", 1);
+  _list.append(group);
+
+  int iCount = cfg->readNumEntry("snippetCount", 0);
+  QString strKeyName="";
+  QString strKeyText="";
+  for ( int i=0; i<iCount; i++) {  //read the snippet-list
+    strKeyName=QString("snippetName_%1").arg(i);
+    strKeyText=QString("snippetText_%1").arg(i);
+
+    QString strNameVal="";
+    QString strTextVal="";
+
+    strNameVal = cfg->readEntry(strKeyName, "");
+    strTextVal = cfg->readEntry(strKeyText, "");
+
+    if (strNameVal != "" && strTextVal != "") {
+      SnippetItem * item = new SnippetItem(group, strNameVal, strTextVal);
+      _list.append(item);
+    }
+  }
+}
+
+
 /*!
     \fn SnippetWidget::initConfig()
     Initial read the cofig file
@@ -255,31 +428,76 @@ void SnippetWidget::initConfig()
 
   _cfg->setGroup("SnippetPart");
 
-  int iCount = _cfg->readNumEntry("snippetCount", 0);
   QString strKeyName="";
   QString strKeyText="";
+  QString strKeyId="";
   SnippetItem *item;
+  SnippetGroup *group;
 
-  for ( int i=1; i<=iCount; i++) {  //read the snippet-list
-    strKeyName=QString("snippetName_%1").arg(i);
-    strKeyText=QString("snippetText_%1").arg(i);
+  kdDebug(9035) << "SnippetWidget::initConfig() " << endl;
+
+  //if entry doesn't get found, this will return -1 which we will need a bit later
+  int iCount = _cfg->readNumEntry("snippetGroupCount", -1);
+
+  for ( int i=0; i<iCount; i++) {  //read the group-list
+    strKeyName=QString("snippetGroupName_%1").arg(i);
+    strKeyId=QString("snippetGroupId_%1").arg(i);
+    strKeyText=QString("snippetGroupLang_%1").arg(i);
 
     QString strNameVal="";
-    QString strTextVal="";
+    int iIdVal=-1;
+    QString strLangVal="";
 
     strNameVal = _cfg->readEntry(strKeyName, "");
-    strTextVal = _cfg->readEntry(strKeyText, "");
+    iIdVal = _cfg->readNumEntry(strKeyId, -1);
+    strLangVal = _cfg->readEntry(strKeyText, i18n("All"));
+    kdDebug(9035) << "Read group " << strNameVal << " " << iIdVal << endl;
 
-    if (strNameVal != "" && strTextVal != "") {
-      item = new SnippetItem(this, strNameVal, strTextVal);
-      _list.append(item);
+    if (strNameVal != "" && iIdVal != -1 && strLangVal != "") {
+      group = new SnippetGroup(this, strNameVal, iIdVal, strLangVal);
+      kdDebug(9035) << "Created group " << group->getName() << " " << group->getId() << endl;
+      _list.append(group);
+      if (group->getLanguage() == i18n("All"))
+        group->setOpen(TRUE);
+      else
+        group->setOpen(FALSE); //groups assigned to certain languages get handled later
     }
   }
 
+  /* Check if the snippetGroupCount property has been found
+     if iCount is -1 this means, that the user has his snippets
+     stored without groups. Therefore we will call the
+     initConfigOldVersion() function below */
+  if (iCount != -1) {
+    iCount = _cfg->readNumEntry("snippetCount", 0);
+    for ( int i=0; i<iCount; i++) {  //read the snippet-list
+        strKeyName=QString("snippetName_%1").arg(i);
+        strKeyText=QString("snippetText_%1").arg(i);
+        strKeyId=QString("snippetParent_%1").arg(i);
+
+        QString strNameVal="";
+        QString strTextVal="";
+        int iParentVal = -1;
+
+        strNameVal = _cfg->readEntry(strKeyName, "");
+        strTextVal = _cfg->readEntry(strKeyText, "");
+        iParentVal = _cfg->readNumEntry(strKeyId, -1);
+        kdDebug(9035) << "Read item " << strNameVal << " " << iParentVal << endl;
+
+        if (strNameVal != "" && strTextVal != "" && iParentVal != -1) {
+        item = new SnippetItem(SnippetItem::findGroupById(iParentVal, _list), strNameVal, strTextVal);
+        kdDebug(9035) << "Created item " << item->getName() << " " << item->getParent() << endl;
+        _list.append(item);
+        }
+    }
+  } else {
+    kdDebug(9035) << "found old version of snippet-configfile" << endl;
+    initConfigOldVersion(_cfg);
+  }
 
   iCount = _cfg->readNumEntry("snippetSavedCount", 0);
 
-  for ( int i=1; i<=iCount; i++) {  //read the snippet-list
+  for ( int i=1; i<=iCount; i++) {  //read the saved-values and store in QMap
     strKeyName=QString("snippetSavedName_%1").arg(i);
     strKeyText=QString("snippetSavedVal_%1").arg(i);
 
@@ -298,6 +516,7 @@ void SnippetWidget::initConfig()
   _SnippetConfig.setDelimiter( _cfg->readEntry("snippetDelimiter", "$") );
   _SnippetConfig.setInputMethod( _cfg->readNumEntry("snippetVarInput", 0) );
   _SnippetConfig.setToolTips( _cfg->readBoolEntry("snippetToolTips", true) );
+  _SnippetConfig.setAutoOpenGroups( _cfg->readNumEntry("snippetGroupAutoOpen", 1) );
 
   _SnippetConfig.setSingleRect( _cfg->readRectEntry("snippetSingleRect", 0L) );
   _SnippetConfig.setMultiRect( _cfg->readRectEntry("snippetMultiRect", 0L) );
@@ -315,9 +534,14 @@ void SnippetWidget::maybeTip( const QPoint & p )
 
 	QRect r = itemRect( item );
 
-	if ( item && r.isValid() && _SnippetConfig.useToolTips() )
+	if (r.isValid() &&
+        _SnippetConfig.useToolTips() )
 	{
-		tip( r, item->getText() );  //show the tip
+        if (dynamic_cast<SnippetGroup*>(item)) {
+		    tip( r, i18n("Language:")+((SnippetGroup*)item)->getLanguage() );  //show the group's language
+        } else {
+		    tip( r, item->getText() );  //show the snippet's text
+        }
 	}
 }
 
@@ -329,19 +553,23 @@ void SnippetWidget::showPopupMenu( QListViewItem * item, const QPoint & p, int )
 {
 	KPopupMenu popup;
 
+	SnippetItem * selectedItem = static_cast<SnippetItem *>(item);
 	if ( item ) {
-		SnippetItem * selectedItem = static_cast<SnippetItem *>(item);
+		popup.insertTitle( selectedItem->getName() );
 
-		popup.insertTitle( i18n("Snippet: ") + selectedItem->getName() );
-
-		popup.insertItem( i18n("Add..."), this, SLOT( slotAdd() ) );
-		popup.insertItem( i18n("Edit..."), this, SLOT( slotEdit() ) );
+		popup.insertItem( i18n("Add Item..."), this, SLOT( slotAdd() ) );
+		popup.insertItem( i18n("Add Group..."), this, SLOT( slotAddGroup() ) );
+        if (dynamic_cast<SnippetGroup*>(item)) {
+            popup.insertItem( i18n("Edit..."), this, SLOT( slotEditGroup() ) );
+        } else {
+            popup.insertItem( i18n("Edit..."), this, SLOT( slotEdit() ) );
+        }
 		popup.insertItem( i18n("Remove"), this, SLOT( slotRemove() ) );
 
 	} else {
 		popup.insertTitle(i18n("Code Snippets"));
 
-		popup.insertItem( i18n("Add..."), this, SLOT( slotAdd() ) );
+		popup.insertItem( i18n("Add Group..."), this, SLOT( slotAddGroup() ) );
 	}
 
 	popup.exec(p);
@@ -367,26 +595,30 @@ QString SnippetWidget::parseText(QString text, QString del)
   QRect rMulti = _SnippetConfig.getMultiRect();
 
   do {
-    iFound = text.find(QRegExp("\\"+del+"[A-Z,a-z,\\s]*\\"+del), iEnd+1);  //find the next variable by this QRegExp
+    iFound = text.find(QRegExp("\\"+del+"[A-Za-z-_0-9\\s]*\\"+del), iEnd+1);  //find the next variable by this QRegExp
     if (iFound >= 0) {
       iEnd = text.find(del, iFound+1)+1;
       strName = text.mid(iFound, iEnd-iFound);
 
-      if ( strName != del+del  &&  mapVar[strName].length() <= 0 ) {  //if not doubel-delimiter and not already in map
-        if (iInMeth == 0) {  //check config, if input-method "single" is selected
-          strMsg=QString(i18n("Please enter the value for <b>%1</b>:")).arg(strName);
-          strNew = showSingleVarDialog( strName, &_mapSaved, rSingle );
-	  if (strNew=="")
-	    return ""; //user clicked Cancle
-	}
+      if ( strName != del+del  ) {  //if not doubel-delimiter 
+        if (iInMeth == 0) { //if input-method "single" is selected
+          if ( mapVar[strName].length() <= 0 ) {  // and not already in map
+            strMsg=i18n("Please enter the value for <b>%1</b>:").arg(strName);
+            strNew = showSingleVarDialog( strName, &_mapSaved, rSingle );
+            if (strNew=="")
+              return ""; //user clicked Cancle
+          } else {
+            continue; //we have already handled this variable
+          }
+        } else {
+          strNew = ""; //for inputmode "multi" just reset new valaue
+        }
       } else {
-        strNew = del;
+        strNew = del; //if double-delimiter -> replace by single character
       }
 
-      if (iInMeth == 0  ||  strName == del+del) {  //check config, if input-method "single" is selected
+      if (iInMeth == 0) {  //if input-method "single" is selected
         str.replace(strName, strNew);
-      } else {
-        strNew = strName;
       }
 
       mapVar[strName] = strNew;
@@ -521,7 +753,9 @@ bool SnippetWidget::showMultiVarDialog(QMap<QString, QString> * map, QMap<QStrin
     r.setWidth(iWidth);
     dlg.setGeometry(r);
   }
-  if ( dlg.exec() == QDialog::Accepted ) {
+  if ( i > 0 && // only if there are any variables
+    dlg.exec() == QDialog::Accepted ) {
+
     QMap<QString, KTextEdit *>::Iterator it2;
     for ( it2 = mapVar2Te.begin(); it2 != mapVar2Te.end(); ++it2 ) {
       if (it2.key() == _SnippetConfig.getDelimiter() + _SnippetConfig.getDelimiter())
@@ -554,6 +788,9 @@ bool SnippetWidget::showMultiVarDialog(QMap<QString, QString> * map, QMap<QStrin
   delete layoutBtn;
   delete layout;
 
+  if (i==0) //if nothing happened this means, that there are no variables to translate
+    return true; //.. so just return OK
+
   return bReturn;
 }
 
@@ -580,13 +817,13 @@ QString SnippetWidget::showSingleVarDialog(QString var, QMap<QString, QString> *
 
   labTop = new QLabel( &dlg, "label" );
   layoutTop->addWidget(labTop, 0, 0);
-  labTop->setText((QString(i18n("Enter the replacement values for ")) + var + ":"));
+  labTop->setText(i18n("Enter the replacement values for %1:").arg( var ));
   layout->addMultiCellLayout( layoutTop, 0, 0, 0, 1 );
 
 
   cb = new QCheckBox( &dlg, "cbVar" );
   cb->setChecked( FALSE );
-  cb->setText("make value &default");
+  cb->setText(i18n( "Make value &default" ));
 
   te = new KTextEdit( &dlg, "teVar" );
   layoutVar->addWidget( te, 0, 1, Qt::AlignTop);
@@ -658,13 +895,20 @@ QString SnippetWidget::showSingleVarDialog(QString var, QMap<QString, QString> *
  */
 bool SnippetWidget::acceptDrag (QDropEvent *event) const
 {
-  kdDebug(9035) << "Format: " << event->format() << endl;
+  kdDebug(9035) << "Format: " << event->format() << "" << event->pos() << endl;
 
-  if (QString(event->format()).startsWith("text/plain") &&
-      static_cast<SnippetWidget *>(event->source()) != this)
-    return true;
-  else
-    return false;
+  QListViewItem * item = itemAt(event->pos());
+
+  if (item &&
+      QString(event->format()).startsWith("text/plain") &&
+      static_cast<SnippetWidget *>(event->source()) != this) {
+    kdDebug(9035) << "returning TRUE " << endl;
+    return TRUE;
+  } else {
+    kdDebug(9035) << "returning FALSE" << endl;
+    event->acceptAction(FALSE);
+    return FALSE;
+  }
 }
 
 //  fn SnippetWidget::slotDropped(QDropEvent *e, QListViewItem *after)
@@ -673,8 +917,12 @@ bool SnippetWidget::acceptDrag (QDropEvent *event) const
     If it is emitted, we need to construct a new snippet entry with
     the data given
  */
-void SnippetWidget::slotDropped(QDropEvent *e, QListViewItem *)
+void SnippetWidget::slotDropped(QDropEvent *e, QListViewItem *item)
 {
+  SnippetGroup *group = dynamic_cast<SnippetGroup *>(item);
+  if (!group)
+    group = dynamic_cast<SnippetGroup *>(item->parent());
+
   QCString dropped;
   QByteArray data = e->encodedData("text/plain");
   if ( e->provides("text/plain") && data.size()>0 ) {
@@ -682,15 +930,45 @@ void SnippetWidget::slotDropped(QDropEvent *e, QListViewItem *)
     QString encData(data.data());
     kdDebug(9035) << "encData: " << encData << endl;
 
-    //... then refill the dialog with the given data
-    m_dialog->snippetName->clear();
-    m_dialog->snippetText->setText(encData);
+    //... then fill the dialog with the given data
+    SnippetDlg dlg(this, "SnippetDlg", true);
+    dlg.snippetName->clear();
+    dlg.snippetText->setText(encData);
 
-    if (m_dialog->exec() == QDialog::Accepted) {
-      _list.append( new SnippetItem(this, m_dialog->snippetName->text(), m_dialog->snippetText->text()) );
+    /*fill the combobox with the names of all SnippetGroup entries*/
+    for (SnippetItem *it=_list.first(); it; it=_list.next()) {
+      if (dynamic_cast<SnippetGroup*>(it)) {
+        dlg.cbGroup->insertItem(it->getName());
+      }
+    }
+    dlg.cbGroup->setCurrentText(group->getName());
+
+    if (dlg.exec() == QDialog::Accepted) {
+      /* get the group that the user selected with the combobox */
+      group = dynamic_cast<SnippetGroup*>(SnippetItem::findItemByName(dlg.cbGroup->currentText(), _list));
+      _list.append( new SnippetItem(group, dlg.snippetName->text(), dlg.snippetText->text()) );
     }
   }
 }
 
 
+/*!
+    \fn SnippetWidget::languageChanged()
+ */
+void SnippetWidget::languageChanged()
+{
+  QStringList langs = m_part->getProjectLanguages();
+
+  for (SnippetItem *it=_list.first(); it; it=_list.next()) {
+    SnippetGroup * group = dynamic_cast<SnippetGroup*>(it);
+    if (group) {
+      if (group->getLanguage() == i18n("All") || langs.contains(group->getLanguage())) {
+        group->setOpen(TRUE);
+      } else {
+        group->setOpen(FALSE);
+      }
+    }
+  }
+}
+
 #include "snippet_widget.moc"
