@@ -53,13 +53,17 @@
 #include "partcontroller.h"
 #include "projectmanager.h"
 #include "core.h"
-#include "settingswidget.h"
 #include "api.h"
 #include "kdevmakefrontend.h"
 #include "toplevel.h"
+#include "kdevplugincontroller.h"
+
+#include "kdevplugininfo.h"
 
 #include "mainwindowshare.h"
 
+#include "shellextension.h"
+
 #ifdef KDE_MAKE_VERSION
 # if KDE_VERSION < KDE_MAKE_VERSION(3,1,90)
 #  define NEED_CONFIGHACK
@@ -253,14 +257,14 @@ void MainWindowShare::slotActiveProcessChanged( KDevPlugin* plugin, bool active
 void MainWindowShare::slotStopPopupActivated( int id )
 {
   KDevPlugin* plugin = activeProcesses.at( id );
-  if ( plugin && plugin->pluginName() == m_stopProcesses->popupMenu()->text( id ) ) {
+  if ( plugin && plugin->info()->genericName() == m_stopProcesses->popupMenu()->text( id ) ) {
     Core::getInstance()->doEmitStopButtonPressed( plugin );
     return;
   } else {
     // oops... list has changed in the meantime
     QString str = m_stopProcesses->popupMenu()->text( id );
     for ( plugin = activeProcesses.first(); plugin; plugin = activeProcesses.next() ) {
-      if ( plugin->pluginName() == str ) {
+      if ( plugin->info()->genericName() == str ) {
   Core::getInstance()->doEmitStopButtonPressed( plugin );
         return;
       }
@@ -275,7 +279,7 @@ void MainWindowShare::slotStopMenuAboutToShow()
 
   int i = 0;
   for ( KDevPlugin* plugin = activeProcesses.first(); plugin; plugin = activeProcesses.next() ) {
-    popup->insertItem( plugin->pluginName(), i++ );
+    popup->insertItem( plugin->info()->genericName(), i++ );
   }
 }
 
@@ -299,41 +303,18 @@ void MainWindowShare::slotSettings()
     KDialogBase dlg(KDialogBase::IconList, i18n("Configure KDevelop"),
                     KDialogBase::Help|KDialogBase::Ok|KDialogBase::Cancel, KDialogBase::Ok, m_pMainWnd,
                     "customization dialog");
+    dlg.setHelp("setup");
+
+    ShellExtension::getInstance()->createGlobalSettingsPage(&dlg);
 
-    SettingsWidget *gsw;
     KConfig* config = kapp->config();
-    if (TopLevel::mode != TopLevel::AssistantMode)
-    {
-        dlg.setHelp("setup");
-        QVBox *vbox = dlg.addVBoxPage(i18n("General"), i18n("General"), DesktopIcon("kdevelop") );
-        gsw = new SettingsWidget(vbox, "general settings widget");
-
-        gsw->projects_url->setMode((int)KFile::Directory);
-
-        config->setGroup("General Options");
-        gsw->lastProjectCheckbox->setChecked(config->readBoolEntry("Read Last Project On Startup",true));
-        config->setGroup("MakeOutputView");
-        gsw->setMessageFont(config->readFontEntry("Messages Font"));
-        gsw->lineWrappingCheckBox->setChecked(config->readBoolEntry("LineWrapping",true));
-        gsw->dirNavigMsgCheckBox->setChecked(config->readBoolEntry("ShowDirNavigMsg",false));
-        gsw->compilerOutputButtonGroup->setRadioButtonExclusive(true);
-        gsw->compilerOutputButtonGroup->setButton(config->readNumEntry("CompilerOutputLevel",0));
-        config->setGroup("General Options");
-        gsw->setApplicationFont(config->readFontEntry("Application Font"));
-        gsw->changeMessageFontButton->setText(gsw->messageFont().family());
-        gsw->changeMessageFontButton->setFont(gsw->messageFont());
-        gsw->changeApplicationFontButton->setText(gsw->applicationFont().family());
-        gsw->changeApplicationFontButton->setFont(gsw->applicationFont());
-        gsw->projects_url->setURL(config->readPathEntry("DefaultProjectsDir", QDir::homeDirPath()+"/"));
-        gsw->embedDesignerCheckBox->setChecked(config->readBoolEntry("Embed KDevDesigner", true));
-    }
 
     config->setGroup("Global Settings Dialog");
     int height = config->readNumEntry( "Height", 600 );
     int width = config->readNumEntry( "Width", 800 );
-    
+
     dlg.resize( width, height );
-  
+
     Core::getInstance()->doEmitConfigWidget(&dlg);
     dlg.exec();
 
@@ -341,23 +322,8 @@ void MainWindowShare::slotSettings()
     config->writeEntry( "Height", dlg.size().height() );
     config->writeEntry( "Width", dlg.size().width() );
 
-    if (TopLevel::mode != TopLevel::AssistantMode)
-    {
-        config->setGroup("General Options");
-        config->writeEntry("Embed KDevDesigner", gsw->embedDesignerCheckBox->isChecked());
-        config->writeEntry("Read Last Project On Startup",gsw->lastProjectCheckbox->isChecked());
-        config->writePathEntry("DefaultProjectsDir", gsw->projects_url->url());
-        config->writeEntry("Application Font", gsw->applicationFont());
-        config->setGroup("MakeOutputView");
-        config->writeEntry("Messages Font",gsw->messageFont());
-        config->writeEntry("LineWrapping",gsw->lineWrappingCheckBox->isChecked());
-        config->writeEntry("ShowDirNavigMsg",gsw->dirNavigMsgCheckBox->isChecked());
-        QButton* pSelButton = gsw->compilerOutputButtonGroup->selected();
-        config->writeEntry("CompilerOutputLevel",gsw->compilerOutputButtonGroup->id(pSelButton)); // id must be in sync with the enum!
-        config->sync();
-        if( API::getInstance()->makeFrontend() )
-            API::getInstance()->makeFrontend()->updateSettingsFromConfig();
-    }
+    if ( dlg.result() != QDialog::Rejected )
+        ShellExtension::getInstance()->acceptGlobalSettingsPage(&dlg);
 }
 
 void MainWindowShare::slotConfigureEditors()
@@ -417,7 +383,7 @@ void MainWindowShare::slotGUICreated( KParts::Part * part )
         kdDebug(9000) << " *** found \"set_confdlg\" action - unplugging" << endl;
         action->unplugAll();
     }
-	
+
 	if ( KAction * action = part->action("file_save") )
 	{
 		kdDebug(9000) << " *** found \"file_save\" action - disconnecting" << endl;
@@ -474,7 +440,7 @@ void MainWindowShare::slotKeyBindings()
             }
             ++it;
         }
-    }  
+    }
   }
 }
 
@@ -501,3 +467,4 @@ void MainWindowShare::slotActivePartChanged( KParts::Part * part )
 }
 
 #include "mainwindowshare.moc"
+//kate: space-indent on; indent-width 4;
