@@ -46,6 +46,7 @@
 #include <knotifydialog.h>
 #include <kedittoolbar.h>
 #include <designer.h>
+#include <kstdaction.h>
 
 #include "kdevplugin.h"
 #include "projectmanager.h"
@@ -56,7 +57,6 @@
 #include "partselectwidget.h"
 #include "api.h"
 #include "core.h"
-#include "settingswidget.h"
 #include "statusbar.h"
 
 #include "kpopupmenu.h"
@@ -67,6 +67,8 @@
 #include "mainwindowshare.h"
 #include "newmainwindow.h"
 
+#include "shellextension.h"
+
 /***************************
 WHAT'S NOT WORKING:
 
@@ -79,15 +81,15 @@ UI mode can now only be changed via a restart. This is intentional!
 ****************************/
 
 NewMainWindow::NewMainWindow(QWidget *parent, const char *name, KMdi::MdiMode mdimode)
- : KMdiMainFrm(parent, name, mdimode )
+ : KMdiMainFrm(parent, name, mdimode ), m_canBeShown(false)
 // ,m_pWindowMenu(0L)
 // ,m_bSwitching(false)
 {
     resize( 800, 600 ); // starts kdevelop at 800x600 the first time
-  
+
 	// isn't it fun with stuff you have no idea what it does?
     this->setManagedDockPositionModeEnabled(true);
-	
+
 	// does this work at all?
     this->setStandardMDIMenuEnabled( false );
 
@@ -96,16 +98,17 @@ NewMainWindow::NewMainWindow(QWidget *parent, const char *name, KMdi::MdiMode md
     int mdiStyle = config->readNumEntry("MDIStyle", 1);
 
     this->setToolviewStyle( mdiStyle ); // KDEV3 style of KMultiTabBar
-    
+
     m_pMainWindowShare = new MainWindowShare(this);
-    
+
 	m_raiseEditor = new KAction( i18n("Raise &Editor"), ALT+Key_C,
                                  this, SLOT(raiseEditor()),
                                  actionCollection(), "raise_editor");
     m_raiseEditor->setToolTip(i18n("Raise editor"));
     m_raiseEditor->setWhatsThis(i18n("<b>Raise editor</b><p>Focuses the editor."));
-        
-   
+
+	KStdAction::configureToolbars( this, SLOT(configureToolbars()), actionCollection(), "set_configure_toolbars" );
+	
 	//@fixme why is this part of KDevMainWindow?
 //    previous_output_view = NULL;
 }
@@ -118,10 +121,7 @@ void NewMainWindow::init() {
 
     setStandardToolBarMenuEnabled( true );
 
-    if (TopLevel::mode == TopLevel::AssistantMode)
-        setXMLFile("kdevassistantui.rc");
-    else
-        setXMLFile("kdevelopui.rc");
+    setXMLFile(ShellExtension::getInstance()->xmlFile());
 
     createFramework();
     createActions();
@@ -138,66 +138,50 @@ void NewMainWindow::init() {
 	readDockConfig( &uiConfig );*/
 
     m_pMainWindowShare->init();
-	
+
 	// remove the kmdi-created menu
 	delete m_pWindowMenu;
-	
-	// get the xmlgui created one instead
-    m_pWindowMenu = static_cast<QPopupMenu*>(main()->child( "window", "KPopupMenu" ));
 
-    if( !m_pWindowMenu )
-	{
-		kdDebug(9000) << "Couldn't find the XMLGUI window menu. Creating new." << endl;
-		
-		m_pWindowMenu = new QPopupMenu( main(), "window");
-		menuBar()->insertItem(i18n("&Window"),m_pWindowMenu);
-	}
-	
-	actionCollection()->action( "file_close" )->plug( m_pWindowMenu );
-	actionCollection()->action( "file_close_all" )->plug( m_pWindowMenu );
-	actionCollection()->action( "file_closeother" )->plug( m_pWindowMenu );
+	setupWindowMenu();
 
-	QObject::connect( m_pWindowMenu, SIGNAL(activated(int)), this, SLOT(openURL(int )) );
-    QObject::connect( m_pWindowMenu, SIGNAL(aboutToShow()), this, SLOT(fillWindowMenu()) );
-			   	   
 	menuBar()->setEnabled( false );
-	
-    if ( PluginController::pluginServices().isEmpty() ) {
+
+    //FIXME: this checks only for global offers which is not quite correct because
+    //a profile can offer core plugins and no global plugins.
+    if ( PluginController::getInstance()->engine().allOffers(ProfileEngine::Global).isEmpty() ) {
         KMessageBox::sorry( this, i18n("Unable to find plugins, KDevelop will not work properly!\nPlease make sure "
                                        "that KDevelop is installed in your KDE directory, otherwise you have to add KDevelop's installation "
                                        "path to the environment variable KDEDIRS and run kbuildsycoca. Restart KDevelop afterwards.\n"
                                        "Example for BASH users:\nexport KDEDIRS=/path/to/kdevelop:$KDEDIRS && kbuildsycoca"),
                             i18n("Could Not Find Plugins") );
     }
-	
+
 	connect( Core::getInstance(), SIGNAL(coreInitialized()), this, SLOT(slotCoreInitialized()) );
-	
+	connect( Core::getInstance(), SIGNAL(projectOpened()), this, SLOT( projectOpened()) );
 	connect( PartController::getInstance(), SIGNAL(partURLChanged(KParts::ReadOnlyPart * )),
 		this, SLOT(slotPartURLChanged(KParts::ReadOnlyPart * )) );
-	
-	connect( PartController::getInstance(), SIGNAL(documentChangedState(const KURL &, DocumentState)), 
+
+	connect( PartController::getInstance(), SIGNAL(documentChangedState(const KURL &, DocumentState)),
 		this, SLOT(documentChangedState(const KURL&, DocumentState )) );
 
 
-	Core::getInstance()->loadLicenses();
-
 	if ( tabWidget() )
 	{
 		KConfig *config = kapp->config();
 		config->setGroup("UI");
-		
+
 		int tabvisibility = config->readNumEntry( "TabWidgetVisibility", KMdi::AlwaysShowTabs );
 		setTabWidgetVisibility( (KMdi::TabWidgetVisibility)tabvisibility );
-		
+
 		bool CloseOnHover = config->readBoolEntry( "CloseOnHover", false );
 		tabWidget()->setHoverCloseButton( CloseOnHover );
-		
+
 		bool CloseOnHoverDelay = config->readBoolEntry( "CloseOnHoverDelay", false );
 		tabWidget()->setHoverCloseButtonDelayed( CloseOnHoverDelay );
-		
+
 		openNewTabAfterCurrent = config->readBoolEntry( "OpenNewTabAfterCurrent", false );
 		showTabIcons = config->readBoolEntry( "ShowTabIcons", true );
-  
+
 		if (config->readBoolEntry( "ShowCloseTabsButton", true ))
 		{
 			QToolButton *but = new QToolButton(tabWidget());
@@ -209,10 +193,25 @@ void NewMainWindow::init() {
 		}
 		tabWidget()->setTabReorderingEnabled(true);
 		connect(tabWidget(), SIGNAL(movedTab(int, int)), this, SLOT(tabMoved(int, int)));
-		connect(tabWidget(), SIGNAL(contextMenu(QWidget*,const QPoint &)), this, SLOT(tabContext(QWidget*,const QPoint &)));		
+		connect(tabWidget(), SIGNAL(contextMenu(QWidget*,const QPoint &)), this, SLOT(tabContext(QWidget*,const QPoint &)));
 	}
 }
 
+void NewMainWindow::configureToolbars( )
+{
+	saveMainWindowSettings( KGlobal::config(), "MainWindow" );
+	KEditToolbar dlg( factory() );
+	connect( &dlg, SIGNAL(newToolbarConfig()), this, SLOT(slotNewToolbarConfig()) );
+	dlg.exec();
+}
+
+void NewMainWindow::slotNewToolbarConfig( )
+{
+	setupWindowMenu();
+	m_pMainWindowShare->slotGUICreated( PartController::getInstance()->activePart() );
+	applyMainWindowSettings( KGlobal::config(), "MainWindow" );
+}
+
 void NewMainWindow::tabContext(QWidget* widget,const QPoint & pos)
 {
 
@@ -238,7 +237,7 @@ void NewMainWindow::tabContext(QWidget* widget,const QPoint & pos)
 				if(PartController::getInstance()->parts()->count() > 1)
 					tabMenu.insertItem( i18n("Close All Others"), 4 );
 
-				if(!dynamic_cast<DocumentationPart*>(ro_part))
+				if(!dynamic_cast<HTMLDocumentationPart*>(ro_part))
 				{
 					if(KParts::ReadWritePart * rw_part = dynamic_cast<KParts::ReadWritePart*>( ro_part ))
 						if(!dynamic_cast<KInterfaceDesigner::Designer*>(ro_part))
@@ -303,7 +302,7 @@ void NewMainWindow::tabContextActivated(int id)
 
 }
 
-NewMainWindow::~NewMainWindow() 
+NewMainWindow::~NewMainWindow()
 {
 	TopLevel::invalidateInstance( this );
 }
@@ -323,7 +322,7 @@ void NewMainWindow::openURL( int id )
 			KURL url( (*it).second );
 			if ( !url.isEmpty() )
 			{
-				PartController::getInstance()->activatePart( PartController::getInstance()->partForURL( url ) );
+				PartController::getInstance()->editDocument( url );
 				return;
 			}
 		}
@@ -331,10 +330,31 @@ void NewMainWindow::openURL( int id )
 	}
 }
 
+void NewMainWindow::setupWindowMenu( )
+{
+	// get the xmlgui created one instead
+	m_pWindowMenu = static_cast<QPopupMenu*>(main()->child( "window", "KPopupMenu" ));
+
+	if( !m_pWindowMenu )
+	{
+		kdDebug(9000) << "Couldn't find the XMLGUI window menu. Creating new." << endl;
+
+		m_pWindowMenu = new QPopupMenu( main(), "window");
+		menuBar()->insertItem(i18n("&Window"),m_pWindowMenu);
+	}
+
+	actionCollection()->action( "file_close" )->plug( m_pWindowMenu );
+	actionCollection()->action( "file_close_all" )->plug( m_pWindowMenu );
+	actionCollection()->action( "file_closeother" )->plug( m_pWindowMenu );
+
+	QObject::connect( m_pWindowMenu, SIGNAL(activated(int)), this, SLOT(openURL(int )) );
+	QObject::connect( m_pWindowMenu, SIGNAL(aboutToShow()), this, SLOT(fillWindowMenu()) );
+}
+
 void NewMainWindow::fillWindowMenu()
 {
 	bool hasWidget = ( PartController::getInstance()->activeWidget() != 0 );	// hmmm... works??
-	
+
 	// clear menu
 	QValueList< QPair< int, KURL > >::ConstIterator it = m_windowList.begin();
 	while ( it != m_windowList.end() )
@@ -342,21 +362,21 @@ void NewMainWindow::fillWindowMenu()
 		m_pWindowMenu->removeItem( (*it).first );
 		++it;
 	}
-	
+
 	int temp = 0;
-		
+
 	if	( m_mdiMode == KMdi::ChildframeMode )
 	{
 		temp = m_pWindowMenu->insertItem(i18n("&Minimize All"), this, SLOT(iconifyAllViews()));
 		m_pWindowMenu->setItemEnabled( temp, hasWidget );
 		m_windowList << qMakePair( temp, KURL() );
-		
+
 		m_windowList << qMakePair( m_pWindowMenu->insertSeparator(), KURL() );
-		
+
 		temp = m_pWindowMenu->insertItem(i18n("&Tile..."), m_pPlacingMenu);
 		m_windowList << qMakePair( temp, KURL() );
 		m_pWindowMenu->setItemEnabled( temp, hasWidget );
-	
+
 		m_pPlacingMenu->clear();
 		m_pPlacingMenu->insertItem(i18n("Ca&scade Windows"), m_pMdi,SLOT(cascadeWindows()));
 		m_pPlacingMenu->insertItem(i18n("Cascade &Maximized"), m_pMdi,SLOT(cascadeMaximized()));
@@ -368,10 +388,10 @@ void NewMainWindow::fillWindowMenu()
 	}
 
 	m_windowList << qMakePair( m_pWindowMenu->insertSeparator(), KURL() );
-	
-	QMap<QString, KURL> map;    
+
+	QMap<QString, KURL> map;
 	QStringList string_list;
-	KURL::List list = PartController::getInstance()->openURLs();	
+	KURL::List list = PartController::getInstance()->openURLs();
 	KURL::List::Iterator itt = list.begin();
 	while ( itt != list.end() )
 	{
@@ -380,17 +400,18 @@ void NewMainWindow::fillWindowMenu()
 		++itt;
 	}
 	string_list.sort();
-	
+
 	list.clear();
 	for(uint i = 0; i != string_list.size(); ++i)
 		list.append(map[string_list[i]]);
-	
+
 	itt = list.begin();
+	int i = 0;
 	while ( itt != list.end() )
 	{
-		temp = m_pWindowMenu->insertItem( (*itt).fileName() );
+		temp = m_pWindowMenu->insertItem( i < 10 ? QString("&%1 %2").arg(i).arg((*itt).fileName()) : (*itt).fileName() );
 		m_windowList << qMakePair( temp, *itt );
-		
+		++i;
 		++itt;
 	}
 }
@@ -432,11 +453,11 @@ void NewMainWindow::slotViewActivated(KMdiChildView* child)
     kdDebug(9000) << "======> view activated: " << child << endl;
     if( !child || !child->focusedChildWidget() )
         return;
-    
+
     emit currentChanged( child->focusedChildWidget() );
 }
 
-void NewMainWindow::createActions() 
+void NewMainWindow::createActions()
 {
     m_pMainWindowShare->createActions();
 
@@ -446,7 +467,7 @@ void NewMainWindow::createActions()
     connect(m_pMainWindowShare, SIGNAL(gotoLastWindow()), this, SLOT(activateLastWin()) );
 }
 
-void NewMainWindow::embedPartView(QWidget *view, const QString &name, const QString& ) 
+void NewMainWindow::embedPartView(QWidget *view, const QString &name, const QString& )
 {
 	if( !view ) return;
 
@@ -454,7 +475,7 @@ void NewMainWindow::embedPartView(QWidget *view, const QString &name, const QStr
     shortName = shortName.right( shortName.length() - (shortName.findRev('/') +1));
 
     KMdiChildView * child = createWrapper(view, name, shortName);
-    
+
     if (showTabIcons)
     {
         const QPixmap* wndIcon = view->icon();
@@ -472,19 +493,20 @@ void NewMainWindow::embedPartView(QWidget *view, const QString &name, const QStr
     addWindow(child, mdiFlags, tabIndex);
 }
 
-void NewMainWindow::embedSelectView(QWidget *view, const QString &name, const QString &toolTip) 
+void NewMainWindow::embedSelectView(QWidget *view, const QString &name, const QString &toolTip)
 {
 	embedView( KDockWidget::DockLeft, view, name, toolTip );
 }
 
-void NewMainWindow::embedSelectViewRight ( QWidget* view, const QString& name, const QString &toolTip) 
+void NewMainWindow::embedSelectViewRight ( QWidget* view, const QString& name, const QString &toolTip)
 {
 	embedView( KDockWidget::DockRight, view, name, toolTip );
-	if (TopLevel::mode == TopLevel::AssistantMode)
+	//FIXME: ok, this is a rude hack
+	if (PluginController::getInstance()->currentProfile() == "KDevAssistant")
 		raiseView(view);
 }
 
-void NewMainWindow::embedOutputView(QWidget *view, const QString &name, const QString &toolTip) 
+void NewMainWindow::embedOutputView(QWidget *view, const QString &name, const QString &toolTip)
 {
 	embedView( KDockWidget::DockBottom, view, name, toolTip );
 }
@@ -539,7 +561,7 @@ void NewMainWindow::embedView( KDockWidget::DockPosition pos, QWidget *view, con
 	{
 		pos = recallToolViewPosition( view->name(), pos );	// we have a new view. where should it go?
 	}
-	
+
 	KMdiMainFrm::addToolWindow( view, pos, getMainDockWidget(), 20, toolTip, name );
 	m_availableToolViews.insert( view, ToolViewData( pos, name, toolTip ) );
 }
@@ -582,18 +604,18 @@ static KDockWidget::DockPosition getDockWidgetDockingBorder( QWidget * w )
 void NewMainWindow::removeView( QWidget * view )
 {
     kdDebug(9000) << k_funcinfo << " - view: " << view << endl;
-    
+
 	if( !view || !view->parentWidget() )
         return;
-    
+
 	kdDebug(9000) << "parentWidget: " << view->parentWidget() << endl;
 
-	if( KMdiChildView * childView = static_cast<KMdiChildView*>(view->parentWidget()->qt_cast("KMdiChildView")) ) 
+	if( KMdiChildView * childView = static_cast<KMdiChildView*>(view->parentWidget()->qt_cast("KMdiChildView")) )
 	{
 		(void) view->reparent(0, QPoint(0,0), false );
 		closeWindow( childView );
-	} 
-	else if( view->parentWidget()->qt_cast("KDockWidget") ) 
+	}
+	else if( view->parentWidget()->qt_cast("KDockWidget") )
 	{
 		rememberToolViewPosition( view->name(), getDockWidgetDockingBorder( view ) );
 		(void) view->reparent(0, QPoint(0,0), false );
@@ -601,7 +623,7 @@ void NewMainWindow::removeView( QWidget * view )
 	}
 }
 
-void NewMainWindow::setViewAvailable(QWidget * view, bool bEnabled) 
+void NewMainWindow::setViewAvailable(QWidget * view, bool bEnabled)
 {
 	if ( !view ) return;
 
@@ -636,10 +658,10 @@ void NewMainWindow::setViewAvailable(QWidget * view, bool bEnabled)
 	}
 }
 
-void NewMainWindow::raiseView(QWidget *view) 
+void NewMainWindow::raiseView(QWidget *view)
 {
 	kdDebug(9000) << k_funcinfo << endl;
-    
+
     if( !view || !view->parentWidget() )
         return;
 
@@ -674,26 +696,8 @@ void NewMainWindow::loadSettings() {
     applyMainWindowSettings(config, "Mainwindow");
 }
 
-void NewMainWindow::setUserInterfaceMode( const QString & )
-{
-/*	
-    // immediately switch the mode likely set in the uimode part
-    if (uiMode == "Childframe") {
-	switchToChildframeMode();
-    }
-    else if (uiMode == "TabPage") {
-	switchToTabPageMode();
-    }
-    else if (uiMode == "Toplevel") {
-	switchToToplevelMode();
-    }
-    else if (uiMode == "KMDI-IDEAl") {
-        switchToIDEAlMode();
-    }
-*/	
-}
 
-void NewMainWindow::saveSettings() 
+void NewMainWindow::saveSettings()
 {
     KConfig *config = kapp->config();
 
@@ -705,13 +709,13 @@ void NewMainWindow::saveSettings()
         appstr = KGlobal::instance()->aboutData()->appName();
 	QString uimode = QString( "%1uimode%2rc" ).arg(appstr).arg( m_mdiMode );
 	KConfig uiConfig( uimode );
-	writeDockConfig( &uiConfig );
+//	writeDockConfig( &uiConfig );
 
 	QValueList<QWidget*> widgetList = m_pToolViews->keys();
 	QValueList<QWidget*>::Iterator it = widgetList.begin();
 	while( it != widgetList.end() )
 	{
-		rememberToolViewPosition( (*it)->name(), getDockWidgetDockingBorder( *it ) );	
+		rememberToolViewPosition( (*it)->name(), getDockWidgetDockingBorder( *it ) );
 		++it;
 	}
 }
@@ -719,7 +723,7 @@ void NewMainWindow::saveSettings()
 void NewMainWindow::raiseEditor( )
 {
 	kdDebug() << k_funcinfo << endl;
-	
+
 	KDevPartController * partcontroller = API::getInstance()->partController();
 	if ( partcontroller->activePart() && partcontroller->activePart()->widget() )
 	{
@@ -740,7 +744,10 @@ void NewMainWindow::setCaption( const QString & caption )
 			projectname.truncate( projectname.length() - suffix.length() );
 		}
 
-		KMdiMainFrm::setCaption( projectname + " - " + caption );
+		if ( !caption.isEmpty() )
+			KMdiMainFrm::setCaption( projectname + " - " + caption );
+		else
+			KMdiMainFrm::setCaption( projectname );
 	}
 	else
 	{
@@ -748,49 +755,25 @@ void NewMainWindow::setCaption( const QString & caption )
 	}
 }
 
-//@fixme - not currently connected - should it be?
-void NewMainWindow::projectOpened() 
+void NewMainWindow::projectOpened()
 {
+	setCaption(QString::null);
 	// why would we reload mainwindow settings on project load?
-	loadSettings();
+	//loadSettings();
 }
 
-void NewMainWindow::prepareToCloseViews()
-{
-  // seems there's nothing to do here
-}
-
-void NewMainWindow::guiRestoringFinished()
-{
-  // seems there's nothing to do here
-}
-
-void NewMainWindow::storeOutputViewTab( )
-{
-  // seems there's nothing to do here
-}
-
-void NewMainWindow::restoreOutputViewTab( )
-{
-  // seems there's nothing to do here
-}
-
-void NewMainWindow::lowerAllViews( )
-{
-  // seems there's nothing to do here
-}
 
 void NewMainWindow::slotPartURLChanged( KParts::ReadOnlyPart * ro_part )
 {
 	kdDebug() << k_funcinfo << endl;
-	
+
 	if ( QWidget * widget = EditorProxy::getInstance()->topWidgetForPart( ro_part ) )
 	{
 		KMdiChildView * childView = dynamic_cast<KMdiChildView*>( widget->parentWidget() );
 		if ( childView )
 		{
 			childView->setMDICaption( ro_part->url().fileName() );
-			
+
 		}
 	}
 }
@@ -816,7 +799,7 @@ void NewMainWindow::documentChangedState( const KURL & url, DocumentState state
 			case Clean:
 				if (showTabIcons)
 					widget->setIcon( SmallIcon("kdevelop", isize));
-				else    
+				else
 					widget->setIcon(QPixmap());
 				break;
 			case Modified:
@@ -839,4 +822,15 @@ void NewMainWindow::tabMoved( int from, int to )
     m_pDocumentViews->insert(to, view);
 }
 
+void NewMainWindow::show( )
+{
+    if (m_canBeShown)
+        KMdiMainFrm::show();
+}
+
+void NewMainWindow::enableShow()
+{
+    m_canBeShown = true;
+}
+
 #include "newmainwindow.moc"
