@@ -33,6 +33,7 @@ class QDomDocument;
 #include "kdevlanguagesupport.h"
 #include "kdevplugin.h"
 #include "kdevcreatefile.h"
+#include "kdevversioncontrol.h"
 
 
 #include "toplevel.h"
@@ -112,18 +113,12 @@ void ProjectManager::createActions( KActionCollection* ac )
   m_closeProjectAction->setToolTip(i18n("Close project"));
   m_closeProjectAction->setWhatsThis(i18n("<b>Close project</b><p>Closes the current project."));
 
-  m_projectOptionsAction = new KAction(i18n("Project &Options..."), "configure", 0,
+  m_projectOptionsAction = new KAction(i18n("Project &Options"), "configure", 0,
                 this, SLOT(slotProjectOptions()),
                 ac, "project_options" );
   m_projectOptionsAction->setToolTip(i18n("Project options"));
   m_projectOptionsAction->setWhatsThis(i18n("<b>Project options</b><p>Lets you customize project options."));
   m_projectOptionsAction->setEnabled(false);
-
-  m_activeLanguage = new KSelectAction(i18n("&Active Language"), 0, ac, "project_active_language");
-  m_activeLanguage->setWhatsThis(i18n("<b>Active language</b><p>Sets the active programming language."));
-  m_activeLanguage->setEnabled(false);
-  connect(m_activeLanguage, SIGNAL(activated(const QString&)),
-          this, SLOT(switchLanguage(const QString&)));
 }
 
 void ProjectManager::slotOpenProject()
@@ -152,18 +147,14 @@ void ProjectManager::slotProjectOptions()
                   KDialogBase::Ok|KDialogBase::Cancel, KDialogBase::Ok, TopLevel::getInstance()->main(),
                   "project options dialog");
 
-	QVBox *box = dlg.addVBoxPage( i18n("General"), i18n("General"), DesktopIcon("kdevelop") );
+	QVBox *box = dlg.addVBoxPage( i18n("General"), i18n("General"), BarIcon( "kdevelop", KIcon::SizeMedium ) );
     GeneralInfoWidget *g = new GeneralInfoWidget(*API::getInstance()->projectDom(), box, "general informations widget");
     connect (&dlg, SIGNAL(okClicked()), g, SLOT(accept()));
 
-  QVBox *vbox = dlg.addVBoxPage( i18n("Plugins"), i18n("Plugins"), DesktopIcon("kdf") );
+  QVBox *vbox = dlg.addVBoxPage( i18n("Plugins"), i18n("Plugins"), BarIcon( "kdf", KIcon::SizeMedium ) );
   PartSelectWidget *w = new PartSelectWidget(*API::getInstance()->projectDom(), vbox, "part selection widget");
-  vbox = dlg.addVBoxPage(i18n("Languages"));
-  LanguageSelectWidget *lw = new LanguageSelectWidget(*API::getInstance()->projectDom(), vbox, "language selection widget");
   connect( &dlg, SIGNAL(okClicked()), w, SLOT(accept()) );
-  connect( &dlg, SIGNAL(okClicked()), lw, SLOT(accept()) );
   connect( w, SIGNAL(accepted()), this, SLOT(loadLocalParts()) );
-  connect( lw, SIGNAL(accepted()), this, SLOT(updateActiveLangMenu()) );
 
   KConfig *config = kapp->config();
   config->setGroup("Project Settings Dialog");
@@ -182,30 +173,6 @@ void ProjectManager::slotProjectOptions()
   config->writeEntry( "Width", dlg.size().width() );
 }
 
-void ProjectManager::updateActiveLangMenu()
-{
-  getGeneralInfo();
-  QStringList list( m_info->m_secondaryLanguages );
-  list.prepend( m_info->m_language ); //make sure primary lang comes first
-  m_activeLanguage->setItems( list );
-  m_activeLanguage->setEnabled( m_info->m_secondaryLanguages.count() > 0 );
-  m_activeLanguage->setCurrentItem(m_activeLanguage->items().findIndex(m_info->m_activeLanguage));
-}
-
-void ProjectManager::switchLanguage(const QString& lang)
-{
-  // make sure there is a project loaded
-  if ( !m_info ) return;
-
-//  PluginController::getInstance()->unloadAllLocalParts();
-  PluginController::getInstance()->unloadPlugins( m_info->m_loadParts );
-  unloadLanguageSupport();
-  m_info->m_loadParts.clear();
-  loadLanguageSupport(lang);
-  loadLocalParts();
-  Core::getInstance()->doEmitLanguageChanged();
-}
-
 void ProjectManager::loadSettings()
 {
 }
@@ -282,8 +249,6 @@ void ProjectManager::slotLoadProject( )
 
   getGeneralInfo();
 
-  updateActiveLangMenu();
-
   if( !loadLanguageSupport(m_info->m_language) ) {
     delete m_info; m_info = 0;
 	TopLevel::getInstance()->main()->menuBar()->setEnabled( true );
@@ -298,7 +263,10 @@ void ProjectManager::slotLoadProject( )
 	kapp->restoreOverrideCursor();
     return;
   }
-
+  
+  TopLevel::getInstance()->statusBar()->message( i18n("Changing plugin profile...") );
+  m_oldProfileName = PluginController::getInstance()->changeProfile(m_info->m_profileName);
+  
   TopLevel::getInstance()->statusBar()->message( i18n("Loading project plugins...") );
   loadLocalParts();
 
@@ -344,10 +312,8 @@ bool ProjectManager::closeProject( bool exiting )
 
   Core::getInstance()->doEmitProjectClosed();
 
-  TopLevel::getInstance()->prepareToCloseViews();
-
-//  PluginController::getInstance()->unloadAllLocalParts();
-  PluginController::getInstance()->unloadPlugins( m_info->m_loadParts );
+  PluginController::getInstance()->unloadProjectPlugins();
+  PluginController::getInstance()->changeProfile(m_oldProfileName);
   unloadLanguageSupport();
   unloadProjectPart();
 
@@ -362,7 +328,6 @@ bool ProjectManager::closeProject( bool exiting )
 
   m_closeProjectAction->setEnabled(false);
   m_projectOptionsAction->setEnabled(false);
-  m_activeLanguage->setEnabled(false);
 
   if ( !exiting )
   {
@@ -473,11 +438,19 @@ void ProjectManager::getGeneralInfo()
   QDomElement generalEl = docEl.namedItem("general").toElement();
 
   m_info->m_projectPlugin = getAttribute(generalEl, "projectmanagement");
+  m_info->m_vcsPlugin = getAttribute(generalEl, "versioncontrol");
   m_info->m_language = getAttribute(generalEl, "primarylanguage");
 
   getAttributeList(generalEl, "ignoreparts", "part", m_info->m_ignoreParts);
   getAttributeList(generalEl, "keywords", "keyword", m_info->m_keywords);
-  getAttributeList(generalEl, "secondaryLanguages", "language", m_info->m_secondaryLanguages);
+
+  //FIXME: adymo: workaround for those project templates without "profile" element
+//  m_info->m_profileName = getAttribute(generalEl, "profile");
+  QDomElement el = generalEl.namedItem("profile").toElement();
+  if (el.isNull())
+      m_info->m_profileName = profileByAttributes(m_info->m_language, m_info->m_keywords);
+  else
+      m_info->m_profileName = el.firstChild().toText().data();
 }
 
 bool ProjectManager::loadProjectPart()
@@ -567,8 +540,6 @@ bool ProjectManager::loadLanguageSupport(const QString& lang)
   API::getInstance()->setLanguageSupport( langSupport );
   PluginController::getInstance()->integratePart( langSupport );
   m_info->m_activeLanguage = lang;
-  m_activeLanguage->setCurrentItem(m_activeLanguage->items().findIndex(lang));
-
   kdDebug(9000) << "Language support for " << lang << " successfully loaded." << endl;
   return true;
 }
@@ -589,7 +560,8 @@ void ProjectManager::loadLocalParts()
 	getGeneralInfo();
 
 	PluginController::getInstance()->unloadPlugins( m_info->m_ignoreParts );
-	PluginController::getInstance()->loadLocalParts( m_info, m_info->m_loadParts, m_info->m_ignoreParts );
+	PluginController::getInstance()->loadProjectPlugins( m_info->m_ignoreParts );
+	PluginController::getInstance()->loadGlobalPlugins( m_info->m_ignoreParts );
 }
 
 KURL ProjectManager::projectFile() const
@@ -633,4 +605,34 @@ bool ProjectManager::loadKDevelop2Project( const KURL & url )
     return loadProject( KURL(projectFile) );
 }
 
+QString ProjectManager::profileByAttributes(const QString &language, const QStringList &keywords)
+{
+    KConfig config(locate("data", "kdevelop/profiles/projectprofiles"));
+    config.setGroup(language);
+    
+    QStringList profileKeywords = QStringList::split("/", "Empty");
+    if (config.hasKey("Keywords"))
+        profileKeywords = config.readListEntry("Keywords");
+    
+    int idx = 0;
+    for (QStringList::const_iterator it = profileKeywords.constBegin();
+        it != profileKeywords.constEnd(); ++it)
+    {
+        if (keywords.contains(*it))
+        {
+            idx = profileKeywords.findIndex(*it);
+            break;
+        }
+    }
+    
+    QStringList profiles;
+    if (config.hasKey("Profiles"))
+    {
+        profiles = config.readListEntry("Profiles");
+        kdDebug() << "IDX: " << idx << "    PROFILE: " << profiles[idx] << endl;
+        return profiles[idx];
+    }
+    return "KDevelop";
+}
+
 #include "projectmanager.moc"
