@@ -14,6 +14,7 @@
 #include <qdir.h>
 #include <qpopupmenu.h>
 #include <qwhatsthis.h>
+#include <qtimer.h>
 
 #include <kpopupmenu.h>
 #include <kdebug.h>
@@ -42,6 +43,7 @@
 #include "kdevmakefrontend.h"
 #include "kdevdifffrontend.h"
 #include "kdevappfrontend.h"
+#include "kdevplugininfo.h"
 #include "domutil.h"
 #include "kdevmainwindow.h"
 #include "kdevproject.h"
@@ -70,20 +72,20 @@ bool g_projectWasJustCreated = false;
 // Plugin factory
 ///////////////////////////////////////////////////////////////////////////////
 
-static const KAboutData data("kdevcvsservice", I18N_NOOP("CvsService"), "1.0");
+static const KDevPluginInfo data("kdevcvsservice");
 typedef KDevGenericFactory<CvsServicePart> CvsFactory;
-K_EXPORT_COMPONENT_FACTORY( libkdevcvsservice, CvsFactory( &data ) )
+K_EXPORT_COMPONENT_FACTORY( libkdevcvsservice, CvsFactory( data ) )
 
 ///////////////////////////////////////////////////////////////////////////////
 // class CvsServicePart
 ///////////////////////////////////////////////////////////////////////////////
 
 CvsServicePart::CvsServicePart( QObject *parent, const char *name, const QStringList & )
-	: KDevVersionControl( "KDevCvsServicePart", "cervisia", parent,
+	: KDevVersionControl( &data, parent,
 						  name ? name : "CvsService" ),
     actionCommit( 0 ), actionDiff( 0 ), actionLog( 0 ), actionAdd( 0 ),
     actionAddBinary( 0 ), actionRemove( 0 ), actionUpdate( 0 ),
-    actionRemoveSticky( 0 ),
+    actionRemoveSticky( 0 ), actionEdit( 0 ), actionEditors(0), actionUnEdit(0),
     actionAddToIgnoreList( 0 ), actionRemoveFromIgnoreList( 0 ),
     actionTag( 0 ), actionUnTag( 0 ),
     actionLogin( 0), actionLogout( 0 ),
@@ -91,11 +93,13 @@ CvsServicePart::CvsServicePart( QObject *parent, const char *name, const QString
 {
     setInstance( CvsFactory::instance() );
 
-    init();
+    m_impl = new CvsServicePartImpl( this );
 
-    /// \FIXME (at all costs!), Ok, this is a crime but for now CvsServicePart is the only implementation
-    /// of KDevVersionControl
-    setVersionControl( this );
+    // Load / store project configuration every time project is opened/closed
+    connect( core(), SIGNAL(projectOpened()), this, SLOT(slotProjectOpened()) );
+    connect( core(), SIGNAL(projectClosed()), this, SLOT(slotProjectClosed()) );
+
+    QTimer::singleShot(0, this, SLOT(init()));
 }
 
 ///////////////////////////////////////////////////////////////////////////////
@@ -110,16 +114,13 @@ CvsServicePart::~CvsServicePart()
 
 void CvsServicePart::init()
 {
+    if ( !m_impl->m_widget ) return;
+
     setupActions();
 
-    m_impl = new CvsServicePartImpl( this );
     // Re-route our implementation signal for when check-out finishes to the standard signal
     connect( m_impl, SIGNAL(checkoutFinished(QString)), SIGNAL(finishedFetching(QString)) );
 
-    // Load / store project configuration every time project is opened/closed
-    connect( core(), SIGNAL(projectOpened()), this, SLOT(slotProjectOpened()) );
-    connect( core(), SIGNAL(projectClosed()), this, SLOT(slotProjectClosed()) );
-
     // Context menu
     connect( core(), SIGNAL(contextMenu(QPopupMenu *, const Context *)),
         this, SLOT(contextMenu(QPopupMenu *, const Context *)) );
@@ -132,6 +133,7 @@ void CvsServicePart::init()
     QWhatsThis::add( m_impl->processWidget(), i18n("<b>CVS</b><p>Concurrent Versions System operations window. Shows output of Cervisia CVS Service.") );
     m_impl->processWidget()->setCaption(i18n("CvsService Output"));
     mainWindow()->embedOutputView( m_impl->processWidget(), i18n("CvsService"), i18n("cvs output") );
+    
 }
 
 ///////////////////////////////////////////////////////////////////////////////
@@ -161,6 +163,21 @@ void CvsServicePart::setupActions()
     actionAdd->setToolTip( i18n("Add file to repository") );
     actionAdd->setWhatsThis( i18n("<b>Add to repository</b><p>Adds file to repository.") );
 
+    actionEdit = new KAction( i18n("&Edit Files"), 0, this, SLOT(slotActionEdit()),
+        actionCollection(), "cvsservice_edit" );
+    actionEdit->setToolTip( i18n("Mark as being edited") );
+    actionEdit->setWhatsThis( i18n("<b>Mark as being edited</b><p>Mark the files as being edited.") );
+
+    actionUnEdit = new KAction( i18n("&Unedit Files"), 0, this, SLOT(slotActionUnEdit()),
+        actionCollection(), "cvsservice_unedit" );
+    actionUnEdit->setToolTip( i18n("Remove editing mark from files") );
+    actionUnEdit->setWhatsThis( i18n("<b>Remove editing mark</b><p>Remove the editing mark from the files.") );
+
+    actionEditors = new KAction( i18n("&Show Editors"), 0, this, SLOT(slotActionEditors()),
+        actionCollection(), "cvsservice_editors" );
+    actionEditors->setToolTip( i18n("Show editors") );
+    actionEditors->setWhatsThis( i18n("<b>Show editors</b><p>Shows the list of users who are editing files.") );
+
     actionAddBinary = new KAction( i18n("Add to Repository as &Binary"), 0, this,
         SLOT(slotActionAddBinary()), actionCollection(), "cvsservice_add_bin" );
     actionAddBinary->setToolTip( i18n("Add file to repository as binary") );
@@ -254,7 +271,7 @@ void CvsServicePart::createNewProject( const QString &dirName )
 
 void CvsServicePart::projectConfigWidget( KDialogBase *dlg )
 {
-	QVBox *vbox = dlg->addVBoxPage( i18n("CvsService"), i18n("CvsService"), BarIcon( icon(), KIcon::SizeMedium) );
+	QVBox *vbox = dlg->addVBoxPage( i18n("CvsService"), i18n("CvsService"), BarIcon( info()->icon(), KIcon::SizeMedium) );
     CvsOptionsWidget *w = new CvsOptionsWidget( (QWidget *)vbox, "cvs config widget" );
     connect( dlg, SIGNAL(okClicked()), w, SLOT(accept()) );
 }
@@ -271,11 +288,6 @@ QWidget* CvsServicePart::newProjectWidget( QWidget *parent )
 
 void CvsServicePart::contextMenu( QPopupMenu *popup, const Context *context )
 {
-  // If the current project doesn't support CVS, we don't
-  // want to confuse the user with a CVS popup menu.
-  if(!project() || !isValidDirectory(project()->projectDirectory()))
-    return;
-
     kdDebug(9006) << "contextMenu()" << endl;
     if (context->hasType( Context::FileContext ) ||
         context->hasType( Context::EditorContext ))
@@ -313,6 +325,12 @@ void CvsServicePart::contextMenu( QPopupMenu *popup, const Context *context )
             id = subMenu->insertItem( actionLog->text(), this, SLOT(slotLog()) );
             subMenu->setWhatsThis(id, i18n("<b>Generate log</b><p>Produces log for this file."));
         }
+        id = subMenu->insertItem( actionEditors->text(), this, SLOT(slotEditors()) );
+        subMenu->setWhatsThis(id, i18n("<b>Show editors</b><p>Shows the list of users who are editing files."));
+        id = subMenu->insertItem( actionEdit->text(), this, SLOT(slotEdit()) );
+        subMenu->setWhatsThis(id, i18n("<b>Mark as beeing edited</b><p>Mark the files as beeing edited."));
+        id = subMenu->insertItem( actionUnEdit->text(), this, SLOT(slotUnEdit()) );
+        subMenu->setWhatsThis(id, i18n("<b>Remove editing mark</b><p>Remove the editing mark from the files."));
         id = subMenu->insertItem( actionAdd->text(), this, SLOT(slotAdd()) );
         subMenu->setWhatsThis(id, i18n("<b>Add to repository</b><p>Adds file to repository."));
         id = subMenu->insertItem( actionAddBinary->text(), this, SLOT(slotAddBinary()) );
@@ -338,6 +356,13 @@ void CvsServicePart::contextMenu( QPopupMenu *popup, const Context *context )
 
         // Now insert in parent menu
         popup->insertItem( i18n("CvsService"), subMenu );
+
+        // If the current project doesn't support CVS, we don't
+        // want to confuse the user with a CVS popup menu.
+        if( !project() || !isValidDirectory( project()->projectDirectory() ) )
+        {
+            subMenu->setEnabled( false );
+        }
     }
 }
 
@@ -418,6 +443,38 @@ void CvsServicePart::slotActionAdd()
 
 ///////////////////////////////////////////////////////////////////////////////
 
+void CvsServicePart::slotActionEdit()
+{
+    KURL currDocument;
+    if (urlFocusedDocument( currDocument ))
+    {
+        m_impl->edit( currDocument );
+    }
+}
+
+///////////////////////////////////////////////////////////////////////////////
+
+void CvsServicePart::slotActionEditors()
+{
+    KURL currDocument;
+    if (urlFocusedDocument( currDocument ))
+    {
+        m_impl->editors( currDocument );
+    }
+}
+///////////////////////////////////////////////////////////////////////////////
+
+void CvsServicePart::slotActionUnEdit()
+{
+    KURL currDocument;
+    if (urlFocusedDocument( currDocument ))
+    {
+        m_impl->unedit( currDocument );
+    }
+}
+
+///////////////////////////////////////////////////////////////////////////////
+
 void CvsServicePart::slotActionAddBinary()
 {
     KURL currDocument;
@@ -538,6 +595,27 @@ void CvsServicePart::slotAdd()
 
 ///////////////////////////////////////////////////////////////////////////////
 
+void CvsServicePart::slotEdit()
+{
+    m_impl->edit( m_urls );
+}
+
+///////////////////////////////////////////////////////////////////////////////
+
+void CvsServicePart::slotUnEdit()
+{
+    m_impl->unedit( m_urls );
+}
+
+///////////////////////////////////////////////////////////////////////////////
+
+void CvsServicePart::slotEditors()
+{
+    m_impl->editors( m_urls );
+}
+
+///////////////////////////////////////////////////////////////////////////////
+
 void CvsServicePart::slotAddBinary()
 {
     m_impl->add( m_urls, true );
