@@ -22,9 +22,6 @@
 #include <kstandarddirs.h>
 #include <kmainwindow.h>
 #include <dcopref.h>
-#include <repository_stub.h>
-#include <cvsservice_stub.h>
-#include <cvsjob_stub.h>
 // CvsService stuff
 #include <repository_stub.h>
 #include <cvsservice_stub.h>
@@ -45,6 +42,7 @@
 #include "diffdialog.h"
 #include "releaseinputdialog.h"
 #include "cvslogdialog.h"
+#include "editorsdialog.h"
 
 #include "changelog.h"
 #include "cvsoptions.h"
@@ -79,14 +77,15 @@ CvsServicePartImpl::CvsServicePartImpl( CvsServicePart *part, const char *name )
         m_widget = new CvsProcessWidget( m_cvsService, part, 0, "cvsprocesswidget" );
         m_scheduler = new DirectScheduler( m_widget );
         m_fileInfoProvider = new CVSFileInfoProvider( part, m_cvsService );
+    
+        connect( core(), SIGNAL(projectOpened()), this, SLOT(slotProjectOpened()) );
     }
     else
     {
-        kdDebug() << "CvsServicePartImpl::CvsServicePartImpl(): somebody kills me because"
+        kdDebug(9006) << "CvsServicePartImpl::CvsServicePartImpl(): somebody kills me because"
             "I could not request a valid CvsService!!!! :-((( " << endl;
     }
 
-    connect( core(), SIGNAL(projectOpened()), this, SLOT(slotProjectOpened()) );
 }
 
 ///////////////////////////////////////////////////////////////////////////////
@@ -108,7 +107,7 @@ CvsServicePartImpl::~CvsServicePartImpl()
 
 bool CvsServicePartImpl::prepareOperation( const KURL::List &someUrls, CvsOperation op )
 {
-    kdDebug() << "===> CvsServicePartImpl::prepareOperation(const KURL::List &, CvsOperation)" << endl;
+    kdDebug(9006) << k_funcinfo << endl;
 
     bool correctlySetup = (m_cvsService != 0) && (m_repository != 0);
     if (!correctlySetup)
@@ -122,7 +121,7 @@ bool CvsServicePartImpl::prepareOperation( const KURL::List &someUrls, CvsOperat
 
     if (!m_part->project())
     {
-        kdDebug(9006) << "CvsServicePartImpl::prepareOperation(): No project???" << endl;
+        kdDebug(9006) << k_funcinfo << "No project???" << endl;
         KMessageBox::sorry( 0, i18n("Open a project first.\nOperation will be aborted.") );
         return false;
     }
@@ -138,7 +137,7 @@ bool CvsServicePartImpl::prepareOperation( const KURL::List &someUrls, CvsOperat
         }
         else // Operation canceled
         {
-            kdDebug() << "===> Operation canceled by user request" << endl;
+            kdDebug(9006) << k_funcinfo << "Operation canceled by user request" << endl;
             return false;
         }
     }
@@ -163,7 +162,7 @@ bool CvsServicePartImpl::prepareOperation( const KURL::List &someUrls, CvsOperat
 
 void CvsServicePartImpl::doneOperation( const KURL::List &/*someUrls*/, CvsOperation /*op*/ )
 {
-    kdDebug(9006) << "CvsServicePartImpl::doneOperation(const KURL::List&, CvsOperation)" << endl;
+    kdDebug(9006) << k_funcinfo << endl;
 
     // @ todo notify clients (filetree) about changed status?)
 }
@@ -189,12 +188,12 @@ QStringList CvsServicePartImpl::fileList( bool relativeToProjectDir ) const
 
 bool CvsServicePartImpl::isRegisteredInRepository( const QString &projectDirectory, const KURL &url )
 {
-    kdDebug(9006) << "===> CvsServicePartImpl::isRegisteredInRepository() here! " << endl;
+    kdDebug(9006) << k_funcinfo << endl;
 
     // KURL::directory() is a bit tricky when used on file or _dir_ paths ;-)
     KURL projectURL = KURL::fromPathOrURL( projectDirectory );
-    kdDebug(9006) << "projectURL = " << projectURL.url() << endl;
-    kdDebug(9006) << "url        = " << url.url() << endl;
+    kdDebug(9006) << k_funcinfo << "projectURL = " << projectURL.url() << endl;
+    kdDebug(9006) << k_funcinfo << "url        = " << url.url() << endl;
 
     if ( projectURL == url)
     {
@@ -207,7 +206,7 @@ bool CvsServicePartImpl::isRegisteredInRepository( const QString &projectDirecto
 
         if (!cvsdir.isValid())
         {
-            kdDebug(9006) << "===> Error: " << cvsdir.path() << " is not a valid CVS directory " << endl;
+            kdDebug(9006) << k_funcinfo << " Error: " << cvsdir.path() << " is not a valid CVS directory " << endl;
             return false;
         }
         CVSEntry entry = cvsdir.fileStatus( url.fileName() );
@@ -219,7 +218,7 @@ bool CvsServicePartImpl::isRegisteredInRepository( const QString &projectDirecto
 
 void CvsServicePartImpl::validateURLs( const QString &projectDirectory, KURL::List &urls, CvsOperation op )
 {
-    kdDebug(9006) << "CvsServicePartImpl::validateURLs() here!" << endl;
+    kdDebug(9006) << k_funcinfo << endl;
 
     // If files are to be added, we can avoid to check them to see if they are registered in the
     // repository ;)
@@ -250,7 +249,7 @@ void CvsServicePartImpl::validateURLs( const QString &projectDirectory, KURL::Li
 
 void CvsServicePartImpl::addToIgnoreList( const QString &projectDirectory, const KURL &url )
 {
-    kdDebug(9006) << "===> CvsServicePartImpl::addToIgnoreList() here! " << endl;
+    kdDebug(9006) << k_funcinfo << endl;
 
     if ( url.path() == projectDirectory )
     {
@@ -274,7 +273,7 @@ void CvsServicePartImpl::addToIgnoreList( const QString &projectDirectory, const
 
 void CvsServicePartImpl::removeFromIgnoreList( const QString &/*projectDirectory*/, const KURL &url )
 {
-    kdDebug(9006) << "===> CvsServicePartImpl::removeFromIgnoreList() here! " << endl;
+    kdDebug(9006) << k_funcinfo << endl;
 
     QStringList ignoreLines;
 
@@ -331,7 +330,7 @@ KDevCore *CvsServicePartImpl::core() const
 
 KDevDiffFrontend *CvsServicePartImpl::diffFrontend() const
 {
-    return m_part->diffFrontend();
+    return m_part->extension<KDevDiffFrontend>("KDevelop/DiffFrontend");
 }
 
 ///////////////////////////////////////////////////////////////////////////////
@@ -356,21 +355,21 @@ void CvsServicePartImpl::logout()
 
 bool CvsServicePartImpl::checkout()
 {
-    kdDebug() << "CvsServicePartImpl::checkout()" << endl;
+    kdDebug(9006) << k_funcinfo << endl;
 
     CheckoutDialog dlg( m_cvsService, mainWindow()->main()->centralWidget() );
 
     if ( dlg.exec() == QDialog::Accepted )
     {
 #if KDE_IS_VERSION(3,2,90)
-        DCOPRef job = m_cvsService->checkout( dlg.workDir(), dlg.serverPath(),	
+        DCOPRef job = m_cvsService->checkout( dlg.workDir(), dlg.serverPath(),
             dlg.module(), dlg.tag(), dlg.pruneDirs(), "", false
         );
-#else    
-        DCOPRef job = m_cvsService->checkout( dlg.workDir(), dlg.serverPath(),	
+#else
+        DCOPRef job = m_cvsService->checkout( dlg.workDir(), dlg.serverPath(),
             dlg.module(), dlg.tag(), dlg.pruneDirs()
         );
-#endif	
+#endif
         if (!m_cvsService->ok()) {
             KMessageBox::sorry( mainWindow()->main(), i18n( "Unable to checkout" ) );
         } else {
@@ -390,7 +389,7 @@ bool CvsServicePartImpl::checkout()
 
 void CvsServicePartImpl::commit( const KURL::List& urlList )
 {
-    kdDebug(9006) << "CvsServicePartImpl::commit() here!" << endl;
+    kdDebug(9006) << k_funcinfo << endl;
     kdDebug(9006) << "Commit requested for " << urlList.count() << " file(s)." << endl;
 
     if (!prepareOperation( urlList, opCommit ))
@@ -421,7 +420,7 @@ void CvsServicePartImpl::commit( const KURL::List& urlList )
         entry.addLines( dlg.logMessage() );
         entry.addToLog( dlg.changeLogFileName() );
 
-        kdDebug( 9999 ) << " *** ChangeLog entry : " <<
+        kdDebug( 9006 ) << " *** ChangeLog entry : " <<
             entry.toString( changeLogPrependString ) << endl;
     }
 
@@ -432,7 +431,7 @@ void CvsServicePartImpl::commit( const KURL::List& urlList )
 
 void CvsServicePartImpl::update( const KURL::List& urlList )
 {
-    kdDebug(9006) << "CvsServicePartImpl::update() here" << endl;
+    kdDebug(9006) << k_funcinfo << endl;
 
     if (!prepareOperation( urlList, opCommit ))
         return;
@@ -462,7 +461,7 @@ void CvsServicePartImpl::update( const KURL::List& urlList )
 
 void CvsServicePartImpl::add( const KURL::List& urlList, bool binary )
 {
-    kdDebug(9006) << "CvsServicePartImpl::add() here" << endl;
+    kdDebug(9006) << k_funcinfo << endl;
 
     if (!prepareOperation( urlList, opAdd ))
         return;
@@ -477,9 +476,60 @@ void CvsServicePartImpl::add( const KURL::List& urlList, bool binary )
 
 ///////////////////////////////////////////////////////////////////////////////
 
+void CvsServicePartImpl::unedit( const KURL::List& urlList)
+{
+    kdDebug(9006) << k_funcinfo << endl;
+
+    if (!prepareOperation( urlList, opUnEdit ))
+        return;
+
+    DCOPRef cvsJob = m_cvsService->unedit( fileList() );
+
+    m_scheduler->schedule( cvsJob );
+    connect( processWidget(), SIGNAL(jobFinished(bool,int)), this, SLOT(slotJobFinished(bool,int)) );
+
+    doneOperation();
+}
+
+///////////////////////////////////////////////////////////////////////////////
+
+void CvsServicePartImpl::edit( const KURL::List& urlList)
+{
+    kdDebug(9006) << k_funcinfo << endl;
+
+    if (!prepareOperation( urlList, opEdit ))
+        return;
+
+    DCOPRef cvsJob = m_cvsService->edit( fileList() );
+
+    m_scheduler->schedule( cvsJob );
+    connect( processWidget(), SIGNAL(jobFinished(bool,int)), this, SLOT(slotJobFinished(bool,int)) );
+
+    doneOperation();
+}
+
+///////////////////////////////////////////////////////////////////////////////
+
+void CvsServicePartImpl::editors( const KURL::List& urlList)
+{
+    kdDebug(9006) << k_funcinfo << endl;
+
+    if (!prepareOperation( urlList, opEditors ))
+        return;
+
+    EditorsDialog * f = new EditorsDialog( m_cvsService );
+    f->show();
+    //the dialog will do all the work
+    f->startjob( fileList()[0] );
+
+    doneOperation();
+}
+
+///////////////////////////////////////////////////////////////////////////////
+
 void CvsServicePartImpl::remove( const KURL::List& urlList )
 {
-    kdDebug(9006) << "CvsServicePartImpl::remove() here" << endl;
+    kdDebug(9006) << k_funcinfo << endl;
 
     if (!prepareOperation( urlList, opRemove ))
         return;
@@ -497,7 +547,7 @@ void CvsServicePartImpl::remove( const KURL::List& urlList )
 
 void CvsServicePartImpl::removeStickyFlag( const KURL::List& urlList )
 {
-    kdDebug(9006) << "CvsServicePartImpl::revert() here" << endl;
+	kdDebug(9006) << k_funcinfo << endl;
 
     if (!prepareOperation( urlList, opUpdate ))
         return;
@@ -521,7 +571,7 @@ void CvsServicePartImpl::removeStickyFlag( const KURL::List& urlList )
 
 void CvsServicePartImpl::log( const KURL::List& urlList )
 {
-    kdDebug(9006) << "CvsServicePartImpl::log() here: " << endl;
+    kdDebug(9006) << k_funcinfo << endl;
 
     if (!prepareOperation( urlList, opLog ))
         return;
@@ -538,7 +588,7 @@ void CvsServicePartImpl::log( const KURL::List& urlList )
 
 void CvsServicePartImpl::diff( const KURL::List& urlList )
 {
-    kdDebug(9006) << "CvsServicePartImpl::diff() here" << endl;
+    kdDebug(9006) << k_funcinfo << endl;
 
     if (!prepareOperation( urlList, opDiff ))
         return;
@@ -568,7 +618,7 @@ void CvsServicePartImpl::diff( const KURL::List& urlList )
 
 void CvsServicePartImpl::tag( const KURL::List& urlList )
 {
-    kdDebug(9006) << "CvsServicePartImpl::tag() here" << endl;
+    kdDebug(9006) << k_funcinfo << endl;
 
     if (!prepareOperation( urlList, opTag ))
         return;
@@ -592,7 +642,7 @@ void CvsServicePartImpl::tag( const KURL::List& urlList )
 
 void CvsServicePartImpl::unTag( const KURL::List& urlList )
 {
-    kdDebug(9006) << "CvsServicePartImpl::unTag() here" << endl;
+    kdDebug(9006) << k_funcinfo << endl;
 
     if (!prepareOperation( urlList, opUnTag ))
         return;
@@ -675,7 +725,8 @@ void CvsServicePartImpl::createNewProject( const QString &dirName,
     kdDebug( 9006 ) << "  ** Will run the following command: " << endl << cmdLine << endl;
     kdDebug( 9006 ) << "  ** on directory: " << dirName << endl;
 
-    m_part->makeFrontend()->queueCommand( dirName, cmdLine );
+    if (KDevMakeFrontend *makeFrontend = m_part->extension<KDevMakeFrontend>("KDevelop/MakeFrontend"))
+        makeFrontend->queueCommand( dirName, cmdLine );
 }
 
 ///////////////////////////////////////////////////////////////////////////////
@@ -727,7 +778,7 @@ void CvsServicePartImpl::flushJobs()
 
 void CvsServicePartImpl::addFilesToProject( const QStringList &filesToAdd )
 {
-    kdDebug( 9006 ) << "====> CvsServicePart::slotAddFilesToProject(const QStringList &)" << endl;
+    kdDebug( 9006 ) << k_funcinfo << endl;
 
     QStringList filesInCVS = checkFileListAgainstCVS( filesToAdd );
     if (filesInCVS.isEmpty())
@@ -753,19 +804,26 @@ void CvsServicePartImpl::addFilesToProject( const QStringList &filesToAdd )
 
 void CvsServicePartImpl::removedFilesFromProject(const QStringList &filesToRemove)
 {
-    kdDebug( 9006 ) << "====> CvsServicePart::slotRemovedFilesFromProject( const QStringList &)" << endl;
+    kdDebug( 9006 ) << k_funcinfo << endl;
 
     QStringList filesInCVS = checkFileListAgainstCVS( filesToRemove );
     if (filesInCVS.isEmpty())
         return;
 
-    int s = KMessageBox::questionYesNo( 0,
+#if KDE_VERSION >= KDE_MAKE_VERSION(3,3,0)
+    int s = KMessageBox::warningContinueCancel( 0,
         i18n("Do you want them to be removed from CVS repository too?\nWarning: They will be removed from disk too."),
         i18n("CVS - Files Removed From Project"),
-        KStdGuiItem::yes(),
-        KStdGuiItem::no(),
+        KStdGuiItem::del(),
         i18n("askWhenRemovingFiles") );
-    if (s == KMessageBox::Yes)
+#else
+    int s = KMessageBox::warningContinueCancel( 0,
+        i18n("Do you want them to be removed from CVS repository too?\nWarning: They will be removed from disk too."),
+        i18n("CVS - Files Removed From Project"),
+        KGuiItem( "&Delete", "editdelete", "Delete item(s)"),
+        i18n("askWhenRemovingFiles") );
+#endif
+    if (s == KMessageBox::Continue)
     {
         kdDebug( 9006 ) << "Removing these files: " << filesInCVS.join( ", " ) << endl;
         const KURL::List urls = KURL::List( filesInCVS );
@@ -814,11 +872,11 @@ void CvsServicePartImpl::slotDiffFinished( bool normalExit, int exitStatus )
     QString diff = processWidget()->output().join("\n"),
         err = processWidget()->errors().join("\n");
 
-    kdDebug( 9999 ) << "diff = " << diff << endl;
-    kdDebug( 9999 ) << "err = " << err << endl;
+    kdDebug( 9006 ) << "diff = " << diff << endl;
+    kdDebug( 9006 ) << "err = " << err << endl;
 
     if (normalExit)
-        kdDebug( 9999 ) << " *** Process died nicely with exit status = " <<
+        kdDebug( 9006 ) << " *** Process died nicely with exit status = " <<
             exitStatus << endl;
     else
         kdDebug( 9999 ) << " *** Process was killed with exit status = " <<
@@ -841,7 +899,7 @@ void CvsServicePartImpl::slotDiffFinished( bool normalExit, int exitStatus )
     if ( !err.isEmpty() )
     {
         int s = KMessageBox::warningContinueCancelList( 0,
-            i18n("CVS outputted errors during diff. Do you still want to continue?"),
+            i18n("CVS output errors during diff. Do you still want to continue?"),
             QStringList::split( "\n", err, false ), i18n("Errors During Diff")
         );
         if ( s != KMessageBox::Continue )
@@ -863,13 +921,13 @@ void CvsServicePartImpl::slotDiffFinished( bool normalExit, int exitStatus )
 
 void CvsServicePartImpl::slotCheckoutFinished( bool exitStatus, int )
 {
-    kdDebug() << "CvsServicePartImpl::slotCheckoutFinished(): job ended with status == "
+    kdDebug(9006) << "CvsServicePartImpl::slotCheckoutFinished(): job ended with status == "
         << exitStatus << endl;
     // Return a null string if the operation was not succesfull
     if (!exitStatus)
         modulePath = QString::null;
 
-    kdDebug() << "   I'll emit modulePath == " << modulePath << endl;
+    kdDebug(9006) << "   I'll emit modulePath == " << modulePath << endl;
 
     emit checkoutFinished( modulePath );
 }
@@ -879,7 +937,7 @@ void CvsServicePartImpl::slotCheckoutFinished( bool exitStatus, int )
 void CvsServicePartImpl::slotJobFinished( bool /*exitStatus*/, int exitCode )
 {
     // Return a null string if the operation was not succesfull
-    kdDebug() << "CvsServicePartImpl::slotJobFinished(): job ended with code == "
+    kdDebug(9006) << "CvsServicePartImpl::slotJobFinished(): job ended with code == "
         << exitCode << endl;
 /*
     // Operation has been successfull
@@ -895,10 +953,13 @@ void CvsServicePartImpl::slotJobFinished( bool /*exitStatus*/, int exitCode )
 
 void CvsServicePartImpl::slotProjectOpened()
 {
-    kdDebug() << "CvsServicePartImpl::slotProjectOpened(): setting work directory to "
+    kdDebug(9006) << "CvsServicePartImpl::slotProjectOpened(): setting work directory to "
         << projectDirectory() << endl;
 
-    m_repository->setWorkingCopy( projectDirectory() );
+    if ( m_repository )
+    {
+        m_repository->setWorkingCopy( projectDirectory() );
+    }
 }
 
 
