@@ -1,5 +1,6 @@
-/* Copyright (C) 2003
-	 Mickael Marchand <marchand@kde.org>
+/**
+
+  	 Copyright (C) 2003-2005 Mickael Marchand <marchand@kde.org>
 
 	 This program is free software; you can redistribute it and/or
 	 modify it under the terms of the GNU General Public
@@ -24,14 +25,18 @@
 #include <qwidget.h>
 #include <kio/job.h>
 #include <kurl.h>
+#include <dcopobject.h>
+#include <subversion_fileinfo.h>
 
 class KDevProject;
 class subversionPart;
 class subversionWidget;
 
-class subversionCore : public QObject
+class subversionCore : public QObject, public DCOPObject
 {
   Q_OBJECT
+  K_DCOP
+
 public:
 		  
   subversionCore(subversionPart *part);
@@ -39,8 +44,15 @@ public:
 	subversionWidget *processWidget() const;
 	void update( const KURL::List&);
 	void commit( const KURL::List&);
+	void add( const KURL::List&);
+	void del( const KURL::List&);
+	void revert( const KURL::List&);
 	void checkout();
 	void createNewProject( const QString& dirName, const KURL& importURL, bool init );
+    KDevVCSFileInfoProvider *fileInfoProvider() const;
+
+k_dcop:
+	void notification( const QString&, int,int, const QString&, int,int ,long int, const QString& );
 
 private slots:
 	void slotEndCheckout( KIO::Job * job );
@@ -54,6 +66,7 @@ private:
 	QGuardedPtr<subversionWidget> m_widget;
 	subversionPart *m_part;
 	QString wcPath;
+	SVNFileInfoProvider *m_fileInfoProvider;
 
 };
 
